(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    194338,       4050]
NotebookOptionsPosition[    186681,       3794]
NotebookOutlinePosition[    187030,       3809]
CellTagsIndexPosition[    186987,       3806]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\
1. Naci povrsinu diska poluprecnika r
Da bismo nasli povrsinu potrebno je da ga zapisemo kao funkciju i da funkciji \
Integrate saopstimo da radi integraciju samo na delu intervala na kome je \
uslov ispunjen. Funkcija je x^2 + y^2 < r^2, dok ogranicavanje intervala \
uticemo pozivom fukcije Boole. Pored ovog ogranicenja, moramo da saopstimo \
Mathematici da je r>0, jer u ce u suprotnom Mathematica pokusati da resi \
Integral u opstem slucaju, tj. pretpostavice da je r realan broj.\
\>", "Text",
 CellChangeTimes->{{3.723538978381872*^9, 3.72353898267188*^9}, {
  3.723539015260337*^9, 3.7235390183023424`*^9}, {3.7235391093441024`*^9, 
  3.7235393450917163`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Integrate", "[", 
  RowBox[{
   RowBox[{"Boole", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"x", "^", "2"}], " ", "+", " ", 
      RowBox[{"y", "^", "2"}]}], " ", "<", " ", 
     RowBox[{"r", "^", "2"}]}], "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"x", ",", " ", 
     RowBox[{"-", "Infinity"}], ",", " ", "Infinity"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", " ", 
     RowBox[{"-", "Infinity"}], ",", " ", "Infinity"}], "}"}], ",", " ", 
   RowBox[{"Assumptions", "\[Rule]", 
    RowBox[{"r", ">", "0"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.72353902274835*^9, 3.7235390889548664`*^9}}],

Cell[BoxData[
 RowBox[{"\[Pi]", " ", 
  SuperscriptBox["r", "2"]}]], "Output",
 CellChangeTimes->{3.7235390978780823`*^9}]
}, Open  ]],

Cell["\<\
2. Resiti povrsinski integral:
Integral_po_S (x^2 + z^2) dS
pri cemu je 
S: x^2/2 + y^2/3 + z^2/2 = 1, y >= 0

Da bismo mogli da resimo integral, neophodno je da prvo parametrizujemo \
povrs. Npr, parametrizacija moze da bude:

x(u, v) = (sqrt(2)*cos(u)*cos(v), sqrt(3)*sin(u), sqrt(2)*cos(u)sin(v)), \
-pi/2 <= u <= pi/2, 0<=v<=pi

BITNO: Mathematica engine je osetljiv na parametrizacije i moze da se dogodi \
da izracunavanje integrala potraje ako parametrizacija nije u skladu sa \
pravilima koja Mathematica koristi prilikom uproscavanja izraza. Ako se to \
dogodi, jedino resenje je promena parametrizacije.

Prvo definisemo povrs kao funkciju dve promenljive\
\>", "Text",
 CellChangeTimes->{{3.723539355886935*^9, 3.723539612647786*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"x", "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"Sqrt", "[", "2", "]"}], "*", 
     RowBox[{"Cos", "[", "u", "]"}], "*", 
     RowBox[{"Cos", "[", "v", "]"}]}], ",", " ", 
    RowBox[{
     RowBox[{"Sqrt", "[", "3", "]"}], "*", 
     RowBox[{"Sin", "[", "u", "]"}]}], ",", " ", 
    RowBox[{
     RowBox[{"Sqrt", "[", "2", "]"}], "*", 
     RowBox[{"Cos", "[", "u", "]"}], "*", 
     RowBox[{"Sin", "[", "v", "]"}]}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.7235396164853935`*^9, 3.723539684985113*^9}}],

Cell["\<\
Zatim, definisemo podintegralnu funkciju kao funkciju tri parametra\
\>", "Text",
 CellChangeTimes->{{3.7235396945947304`*^9, 3.723539721723178*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"{", 
    RowBox[{"x_", ",", "y_", ",", "z_"}], "}"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"x", "^", "2"}], " ", "+", " ", 
   RowBox[{"z", "^", "2"}]}]}]], "Input",
 CellChangeTimes->{{3.7235397252175837`*^9, 3.723539740692811*^9}}],

Cell["\<\
Na kraju, potrebno je da resimo integral. Potrebno je da nadjemo normu \
vektorskog proizvoda parcijalnih izvoda parametrizacije da bismo resili \
integral\
\>", "Text",
 CellChangeTimes->{{3.7235397621584487`*^9, 3.723539815151742*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Integrate", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{"x", "[", 
      RowBox[{"u", ",", "v"}], "]"}], "]"}], "*", 
    RowBox[{"Norm", "[", 
     RowBox[{"Cross", "[", 
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"x", "[", 
          RowBox[{"u", ",", "v"}], "]"}], ",", "u"}], "]"}], ",", " ", 
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"x", "[", 
          RowBox[{"u", ",", "v"}], "]"}], ",", " ", "v"}], "]"}]}], "]"}], 
     "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", " ", 
     RowBox[{
      RowBox[{"-", "Pi"}], "/", "2"}], ",", 
     RowBox[{"Pi", "/", "2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", " ", "0", ",", " ", "Pi"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.723539817413746*^9, 3.7235398847590647`*^9}, {
  3.7235399233847322`*^9, 3.7235399251475353`*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", "\[Pi]", " ", 
  RowBox[{"(", 
   RowBox[{"10", "+", 
    RowBox[{"3", " ", 
     SqrtBox["2"], " ", 
     RowBox[{"ArcTan", "[", 
      FractionBox["1", 
       SqrtBox["2"]], "]"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.7235399292659426`*^9}]
}, Open  ]],

Cell["\<\
3. Nacrtati aproksimaciju Tejlorovog razvoja funkcije sin(x) u tacki 0.
Napravicemo niz aproksimacija dunkcije sin(x) polinommima od 1. do 20. \
stepena. 
Tejlorov razvoj radimo funkcijom Series,
Dobijene polinome moramo da normalizujemo da bismo mogli da ih nacrtamo, a to \
radimo sa funkcijom Normal
S obzirom da nam treba niz polinoma, moramo da koristimo funkciju Table, i na \
kraju da bismo nacrtavli sve ove aproksimacije moramo da ih izracunamo na \
nekom intervalu za sta koristimo funkciju Evaluate. I na kraju to sve, treba \
da upakujemo u Plot. 
U jednom izrazu dobija se sledece:\
\>", "Text",
 CellChangeTimes->{{3.7235399765652256`*^9, 3.723540174935174*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"Normal", "[", 
       RowBox[{"Series", "[", 
        RowBox[{
         RowBox[{"Sin", "[", "x", "]"}], ",", " ", 
         RowBox[{"{", 
          RowBox[{"x", ",", " ", "0", ",", " ", "n"}], "}"}]}], "]"}], "]"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"n", ",", " ", "0", ",", "20"}], "}"}]}], "]"}], "]"}], ",", 
   " ", 
   RowBox[{"{", 
    RowBox[{"x", ",", " ", "0", ",", " ", 
     RowBox[{"2", "Pi"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7235401775403786`*^9, 3.7235402432944937`*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJxF0H0s1AEYB/Bzd3Gn1N11TnZDiDZsaq3V7U5kQizjWm9Upx+KU+68rCLN
lE6jdH7JvHapOaxRJq4kLLuFySwiLpEoLW+Zbtd5q7Y8z7N9993nv+8ee0Im
jqJSKJRDf/OvaS3m3V92p++j/D+n781C27sSzzUbn7pHDpIy8AQ32tBApoGH
fDNel5N3wO8l5PZSUgUWn7ceKiCfgHPnT9blky1goTbA3DuxByxPCTpTJ/8A
vvA8KofqOArumzzIrCDGwVnuekrDiUlwvGv7vdbyKdwfEVszHDcHJl4dDVae
nQdH/Oxrbb25AL61QyNTK/RgaqtmT0aKAcx2CeweKTCC/VXej+bIJbDVbJdv
mmYFXPSm0YQWQ/Fas8hm/+rWSBOw6yhr/GoSFVxdyYmuT6CBUz+d6nVV0MHx
or2B9/PWgY0qH+KH0hTcIy8Kv/TQDCzwc1gZLmOAOw4IKr1KmODy2kLB2GNz
sKWjm/R01XrwOxPGNeumDeB6RqK6p8MC7GbJkhLajeDZHD13V/8msGNmprtM
ygKPheqGvL+h/Sd6f9fHscGXE6KiedPooIbiAN5FDnhmSZpK06PLBtKfxSVu
xn9Ee4QnL6JtlnPD4lO44K9+2Z0MuiW4zbnL0zYbLWWo6fZMHljzYJtHWy66
WyjSitlWYIO0+HB4Dro9WHXEgrcFTAhEFRV56Jjpt78+5qPlZRIfTiE6jXn9
c2opumSwgy9Wo/uTjymXNOiAxoTkEB06JI7erhhGH3fI5zWNoM9lvahzHkdn
hFJmFqfQzcbbhHoFra2xq9VRrMFdRO0qi4bWdfaVXDFDG4r4A8Es9GpQtZOC
gzaleSa95KK5sQTb2RrNt1uQhPHRDr03apQ2aJdMq2WtHXqnsCpw0R79BwCw
DvY=
       "]]},
     Annotation[#, "Charting`Private`Tag$16587#1"]& ], 
    TagBox[
     {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBWIQzbyf69xj00Y7GK36cp+13OR4exj9a4N+ys1J+XD6
qUjGj22T6uH0LbeWQ0sn9cPpq/GT1OdOmg+ng3Ikb82YtB5OT/wUs3napP1w
2vqoF5dT8QU4XVDll7i54Aaczt2R2sek/ABOX3nhybk86Qmc7tL/xrAt8gWc
LtQ+MfXA0jdw+ldy9rq7eR/gdNLesIAJaZ/gdPLHKwcOdHyB0z0G2/OXtX2D
00wHtpu3VP2A04Ja3ufuz/gFpz3mOy3+MOkPnBZ/f8atfvs/OD3r+C5G5kwG
BxhtI+v4XyGFEU5rPxB4UlvCBKfXrhDK2FrEDKdr7sVe1m5jgdOFNhbe86aw
wulf812SXk9gg9MXCmYllC9ih9OW7kr/7i7kgNMnXS1XOMzhhNNLN860fLSa
C06LKutkxa3khtOXGDmaJPfwwOmtHMXLLpzkhdOG6rbPI2fxwWkAYqQVRA==

       "]]},
     Annotation[#, "Charting`Private`Tag$16587#2"]& ], 
    TagBox[
     {RGBColor[0.560181, 0.691569, 0.194885], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBWIQzbyf69xj00Y7GK36cp+13OR4exj9a4N+ys1J+XD6
qUjGj22T6uH0LbeWQ0sn9cPpq/GT1OdOmg+ng3Ikb82YtB5OT/wUs3napP1w
2vqoF5dT8QU4XVDll7i54Aaczt2R2sek/ABOX3nhybk86Qmc7tL/xrAt8gWc
LtQ+MfXA0jdw+ldy9rq7eR/gdNLesIAJaZ/gdPLHKwcOdHyB0z0G2/OXtX2D
00wHtpu3VP2A04Ja3ufuz/gFpz3mOy3+MOkPnBZ/f8atfvs/OD3r+C5G5kwG
BxhtI+v4XyGFEU5rPxB4UlvCBKfXrhDK2FrEDKdr7sVe1m5jgdOFNhbe86aw
wulf812SXk9gg9MXCmYllC9ih9OW7kr/7i7kgNMnXS1XOMzhhNNLN860fLSa
C06LKutkxa3khtOXGDmaJPfwwOmtHMXLLpzkhdOG6rbPI2fxwWkAYqQVRA==

       "]]},
     Annotation[#, "Charting`Private`Tag$16587#3"]& ], 
    TagBox[
     {RGBColor[0.922526, 0.385626, 0.209179], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwl13k0VP//B/AxEh9LEYXyadGmkOpDVOp5kyylLBUtSEKSotWapZREJZJ9
SUiJhPCpLCmFfKII0U5jxsy91plhiO/9nd8fc17nce45z3Pn/Xq/X+d9Fzl7
2bgyGQzGD/r3f1W8Svp9t17oZkHl/9elnMqN82MPIfFJ+7AaXUWFOi6fY7yQ
vLfEuJWuv5XcR0tjgqH1qMI/k66dJmE12TE3kfXIqXE3XT8dilmeGpOOQEl5
q7230mHjqdqZEPMYSpoaQX7XH+PWkH3xnZgqyGjXmaoGVWFj7XZpozPNkNn9
3/xu42Z4++86XOzdgd7Xi/bc7WjHiXLXG8zFP2DaqdLf1fsNrWzzv+4798Bc
QvlEvlg3rukIGKX72TjkJy6jxmDB38dck+XBhtimvyp3ybJwrCpl75xANjgR
6a7+KiyYWW59eD6NjQPN94NerGZB0it6t343G7qXd+7kOrEQVrAyp9yTg4cb
Fk3vr2IhSPvQjufBfSj5J1zH07cXpzTr4qqzeXhia1Cw/CMbPa49IRmlPDS5
O4QTX9iwzWB4hrzlYd9bbxdrFhsbZq83Ijg8/N6aqnxQxAZz6gFVpUXCce2D
b3LqHMR8jDStKiZxM8OzlefFQZGf5VjFSwqs9PTLXhJ9WFJyvCf1I4VrgzNr
g2f04Q4V3nShm4LJ4W2nw5X74H+kOnuTRD+2ntsgfmFFH4x2rrGpMOtHlRsn
gLGzDy0LFfNeNPXjouaGfJeYPoiOHC/4enIAWnOz14XO4cJJYdj3xfkBZMlZ
B5B/c1Fb6b81OWgAjZXuddZLuYhWvdax78YAbF3SPZm6XCxvymW25g/goviV
0+LWXOzZwLJt4A0g793cBaERXBTIH54q9RiElOVZG6sRLpQq2fVxpwfh8Ttq
a6mIC7/j3rfP+g/i07U1rxTFeDB+E7xi7bVBjMh2Oz6V46ErIG13/oNBXNbb
mhqzjAep3q7799iDcLPu/PHElgfnCluraLch9AWf63Qv5GFtqcosVa8h1NVv
v6NJ94H5uLPlrs8QLo5Srd3PecjMcLQrvjqE8fP6b3Xpvvy65ObY9nAIDSof
hHZf6bzt5z3V+ocQLzhqni5JYu1Wg1XZwiGECE5zy2RJMA1F/dqMYbCykmpq
FUhkagedgcIwYoNbJqrnkfglf8Xf+Z9hGO8cVtHTIeHcHnc112cYr6y0Cmfu
ofOa7bavCRlGYYa5g98+Oq9eVfbZ1WH86/5hsN2eznuWevNd4jCiWoorzrjS
eanZd6jnw5im17hv6Xk6z+Vpli5jBGPaUfaecXSeg49bhdQIuo8mrFdPpPNs
12uYKIwgotu+sDGFzjOtyLNTH8GZWZl2U/fovJW1Rf7GI7jttVSi6wmJI4Ot
1dVXR1CnbZ1y9B0JJ/9ou/LoEXxh8G3WvidhL25BPU4YgURac9tQMwnb2a/m
peeOwNDv8Lq9bSTM1j85f6FuBBcvm7PSfpDYVuMpd655BKkBMgnK3SSMdmhk
eXaMQPrlMeHl3yQ2OqR/OMgegW+g9uOtfSRWhV7X2iDFBz98zW2jYRIrpc1f
rZHnY6hBz9idT2J57LQDK1T4CPy14eIlIYmF2QHhKhp8tH/wS0gaJ6FYf+yX
wJQP0aWVVdvFKcjbLPWjLPko2RTnrSZBQbbrx0yWHR8G1q7R3dMpTCftNn06
SrvuqIyNNIVReZOE4nA+POv2hjyWpzCSKKaTd5OPavUd67RmURhUr6jNjOdD
xV56Y5oihT5d3eFb9/k4U6CyyHkOhd6K/oiIx3y8YYeIipUp9JjkLQwt4+OZ
8e9Z4yoUvu5T3+X9lg+NrNYB93kUOn9+7TnaxMdAnW/BTTUKbR6JAYfa+Ri1
3pGc9zeF5kD5B7t6+XBryR+qWUChUaIRJv18zCVt91YupFB/I7xtk5CPR/lO
7QWLKNRkTIprSwog5Va3wmsxhcoVz5KWzBRgQTCGNi+h8Lzo3Bo1ZQGKQs0b
xJdSKN+4pk5xgQDHJofyK2iXvOY5yiwXgHPZLNFzGYUnO3P5TB0BunJtr8ov
p1DQdiRKtE4AlnCFzwPa99md/3JMaNvbGD/ToJB16o7Vz10CrLhdPXftCgoZ
IuveDlsBFm9Y9jONduoluaBmRwECvt+MZaykkCRbr1TnJkCnkvQqO9p34sLy
qk4K0ONx91Em7dj5hFHZeQGMTzvLdNOOvj/eURAkQMbz/SYqmhSiVpd55VwR
IL09dr8R7Ya17axzNwQIvan40om2lJ7QYdsdAaaxb7mfpW2ir/xJKU0A09G9
Fhdoh63Xt+jJFsCjPcc9gHbNRrtXxfkCRKW8+/ckbcZmnw2Xngrw3lHG0I72
ZiL+iU2FADv18rm6tAOMyjTUawXQ0h99LUm73Lg9fbBRgIiAf1430e8rMBHO
edkqQJhqzu8o2rrmyjeivwhgqBG/FLRP79CXcOoRoLVyZwiLXp/CnXaBOjwB
jo7ID12kTVn6DE8OCzDnx3IfJdpaNvEe78cFEE/8LJNMr7fHnrKfqeJCWKw7
8WgO7Vzb9n0nZIRQaFqxN5zuD2ufsMlQUYjT/rZMku7nkoPKprLzhLhhuaHQ
lPZhB/3KLnUhLruqHYyn+592yE4vb6UQPi1bp7ro/fLlsM8j/7VCXCoUJsym
vc+tLEnVSIjjSovSjqrT/XJvV+CYCxFWv4QZQu+/Vg/h1XJrIQy2f7C4Tu9P
Ky99H7vDQnClt4RfmU/B1Ldsd1yIEMPyRhrDqvT6+7c3uFwVwuqhzf4i+nzU
BAq36EYLYVxnvNuNPj+bQ/VXt6QLcYrixDxSorDuWpmsQpUQ1scnO57MoHA2
qv3SjzdCfCv8yZ4jR6HohlD0+L0QDN3v97xlKGjH6nN2fRPiouU2WaYU/f9T
ymqj/ggx6By2OYVBwTmt3dBeYhQpagzkTJLIyBAWa8qNorPxfWPWBAm1bP3M
BrVRRJ4IDQ0epedLQVmQlOEoNuszex/20/O1ukw/zH8UOctznNq6SDyUm5Xz
5+Io3P/LjuB1kLA56KnkEzmKh5Ezh0Y+kbgnWDh4LGUUX/LVTn5pImGsfe2h
ZeUoiBl/rku8InElyf7vecwxLDv2ceuLHHoesksjb0uPYZ8LW2Mkk0SbnoJI
TnEMtey9YvPT6Xn4obaNsWQMPpy1fqbxJOokdaJZ28bo/rZODVwhIX1OTLwo
Ygx5HYVIOkKiqObgKc2YMfTqlizodyRxQL70e1bSGOZETuToHSCRl+fxIj5v
DBdC7RLirUhY/Go5d+G/MRTOmxNaYEjSuTlsMwURWnWKtiyZRUJh5Y733xNE
2K5hqj+jiAeWZLpCXYYILo4zoyfzeHj2e2hPYS79PJbR+5O+F7ncTeoKKRch
trovODSRh3KVPvaiDhEeJZUNLg7hwVEyQtxFeRyZnyfPDG3n4VHPGwN23Djq
etM5SW1chNbMDWxOHccH1/LI7vdc+j51sqo8exxW85wK57/lgmE/xyTi6Tga
hjmnPMu42N3iunvlp3EQjdXHXOO5EL2cdtJTaQIt903e1e/hwizd6N5AzASa
T8602FLbh/C65q8XkydwUvy6q+TzPrwZdFSZnTUBnbJSxYrCPmwzDri+/ukE
+sac5gqT6fsUp9jnYvsELB1sTLNP9cHwn6UWSmp/YLK45MNv1T6sfivJ18/+
A4LdZPDJgQOvgTidhvw/2GP75lCYNQcFqks87Etpf5y4oL6NA21P4nvI2z8Y
OhUYpanFwUoFv/p6zh/crpZ09x5j0+e3L/XgqklMW3zgXXU0G8r9jSbBZZNo
Ndjesr+oFwm3qg5zqibRF7lsl3pWL1R0iwJ3101CfeX9N5/jaPvFFy3/PIln
KsLU2X69mCvuPL9ZNInyM0FHqjf3Yr6ykL9w8xTqGqL1v71hYRkWZde8nsKj
HYMn5zb8RtLbZ2LixxiEhazs2ejkbgz8KPTr92QQvkJzB71r3TAV5Qx2eTOI
DtLXt8G3GyNasT9LfBlECvemXu3ebuyKOf7S7SqDMCvlOk3M6AbTQS204T6D
aP2Zs+pk0C8cH7rAiGExCJHDDYNt1j9h+PeWqYUuYoR7svfarsivMLNvPe3s
LkaYjbEnnBy+Yk/yUdY9TzGikfvJsWrVVxxXvfHfsnNixLRVYTUSH74gaXZX
stYVMSIk1Hu8TPELRuXOGRjkihHV+gG1D251omQy95QlT4yw9+83D/Zqh+YP
+Z4LZ5mEygKpW22FzdjVu7DmvC+TsIpUPPsngP7+oFZneAUyidWz/TlTJs0o
mbCyPxzGJIipaR2r/m2CoeqtVuPbTELeaCdngex7WNgo1MqUMAmGWftpIqsB
nq8VchKHmUSzXsNZudRXyM+d5f70tDhR7dOgc/9pJgK/ObRoXplGEGLNFhc6
mqpOGRrsSLstQQTqbqpsdvxVJUo3duZGTyesjHY3vPUiq5q9k5x8MiWJDEPV
YvEgftV6U/XJr3eliF0GTxLrYyeq6retzyVS/iJ0ruXLLVVnVmc/SVz/K0+a
ONN8LKvzxfTq2Yu1PBwfyBAB09PvKZyTqZ53N6ReebEsUXBLyeNOv1z1/wDh
oxR7
       "]]},
     Annotation[#, "Charting`Private`Tag$16587#4"]& ], 
    TagBox[
     {RGBColor[0.528488, 0.470624, 0.701351], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwl13k0VP//B/AxEh9LEYXyadGmkOpDVOp5kyylLBUtSEKSotWapZREJZJ9
SUiJhPCpLCmFfKII0U5jxsy91plhiO/9nd8fc17nce45z3Pn/Xq/X+d9Fzl7
2bgyGQzGD/r3f1W8Svp9t17oZkHl/9elnMqN82MPIfFJ+7AaXUWFOi6fY7yQ
vLfEuJWuv5XcR0tjgqH1qMI/k66dJmE12TE3kfXIqXE3XT8dilmeGpOOQEl5
q7230mHjqdqZEPMYSpoaQX7XH+PWkH3xnZgqyGjXmaoGVWFj7XZpozPNkNn9
3/xu42Z4++86XOzdgd7Xi/bc7WjHiXLXG8zFP2DaqdLf1fsNrWzzv+4798Bc
QvlEvlg3rukIGKX72TjkJy6jxmDB38dck+XBhtimvyp3ybJwrCpl75xANjgR
6a7+KiyYWW59eD6NjQPN94NerGZB0it6t343G7qXd+7kOrEQVrAyp9yTg4cb
Fk3vr2IhSPvQjufBfSj5J1zH07cXpzTr4qqzeXhia1Cw/CMbPa49IRmlPDS5
O4QTX9iwzWB4hrzlYd9bbxdrFhsbZq83Ijg8/N6aqnxQxAZz6gFVpUXCce2D
b3LqHMR8jDStKiZxM8OzlefFQZGf5VjFSwqs9PTLXhJ9WFJyvCf1I4VrgzNr
g2f04Q4V3nShm4LJ4W2nw5X74H+kOnuTRD+2ntsgfmFFH4x2rrGpMOtHlRsn
gLGzDy0LFfNeNPXjouaGfJeYPoiOHC/4enIAWnOz14XO4cJJYdj3xfkBZMlZ
B5B/c1Fb6b81OWgAjZXuddZLuYhWvdax78YAbF3SPZm6XCxvymW25g/goviV
0+LWXOzZwLJt4A0g793cBaERXBTIH54q9RiElOVZG6sRLpQq2fVxpwfh8Ttq
a6mIC7/j3rfP+g/i07U1rxTFeDB+E7xi7bVBjMh2Oz6V46ErIG13/oNBXNbb
mhqzjAep3q7799iDcLPu/PHElgfnCluraLch9AWf63Qv5GFtqcosVa8h1NVv
v6NJ94H5uLPlrs8QLo5Srd3PecjMcLQrvjqE8fP6b3Xpvvy65ObY9nAIDSof
hHZf6bzt5z3V+ocQLzhqni5JYu1Wg1XZwiGECE5zy2RJMA1F/dqMYbCykmpq
FUhkagedgcIwYoNbJqrnkfglf8Xf+Z9hGO8cVtHTIeHcHnc112cYr6y0Cmfu
ofOa7bavCRlGYYa5g98+Oq9eVfbZ1WH86/5hsN2eznuWevNd4jCiWoorzrjS
eanZd6jnw5im17hv6Xk6z+Vpli5jBGPaUfaecXSeg49bhdQIuo8mrFdPpPNs
12uYKIwgotu+sDGFzjOtyLNTH8GZWZl2U/fovJW1Rf7GI7jttVSi6wmJI4Ot
1dVXR1CnbZ1y9B0JJ/9ou/LoEXxh8G3WvidhL25BPU4YgURac9tQMwnb2a/m
peeOwNDv8Lq9bSTM1j85f6FuBBcvm7PSfpDYVuMpd655BKkBMgnK3SSMdmhk
eXaMQPrlMeHl3yQ2OqR/OMgegW+g9uOtfSRWhV7X2iDFBz98zW2jYRIrpc1f
rZHnY6hBz9idT2J57LQDK1T4CPy14eIlIYmF2QHhKhp8tH/wS0gaJ6FYf+yX
wJQP0aWVVdvFKcjbLPWjLPko2RTnrSZBQbbrx0yWHR8G1q7R3dMpTCftNn06
SrvuqIyNNIVReZOE4nA+POv2hjyWpzCSKKaTd5OPavUd67RmURhUr6jNjOdD
xV56Y5oihT5d3eFb9/k4U6CyyHkOhd6K/oiIx3y8YYeIipUp9JjkLQwt4+OZ
8e9Z4yoUvu5T3+X9lg+NrNYB93kUOn9+7TnaxMdAnW/BTTUKbR6JAYfa+Ri1
3pGc9zeF5kD5B7t6+XBryR+qWUChUaIRJv18zCVt91YupFB/I7xtk5CPR/lO
7QWLKNRkTIprSwog5Va3wmsxhcoVz5KWzBRgQTCGNi+h8Lzo3Bo1ZQGKQs0b
xJdSKN+4pk5xgQDHJofyK2iXvOY5yiwXgHPZLNFzGYUnO3P5TB0BunJtr8ov
p1DQdiRKtE4AlnCFzwPa99md/3JMaNvbGD/ToJB16o7Vz10CrLhdPXftCgoZ
IuveDlsBFm9Y9jONduoluaBmRwECvt+MZaykkCRbr1TnJkCnkvQqO9p34sLy
qk4K0ONx91Em7dj5hFHZeQGMTzvLdNOOvj/eURAkQMbz/SYqmhSiVpd55VwR
IL09dr8R7Ya17axzNwQIvan40om2lJ7QYdsdAaaxb7mfpW2ir/xJKU0A09G9
Fhdoh63Xt+jJFsCjPcc9gHbNRrtXxfkCRKW8+/ckbcZmnw2Xngrw3lHG0I72
ZiL+iU2FADv18rm6tAOMyjTUawXQ0h99LUm73Lg9fbBRgIiAf1430e8rMBHO
edkqQJhqzu8o2rrmyjeivwhgqBG/FLRP79CXcOoRoLVyZwiLXp/CnXaBOjwB
jo7ID12kTVn6DE8OCzDnx3IfJdpaNvEe78cFEE/8LJNMr7fHnrKfqeJCWKw7
8WgO7Vzb9n0nZIRQaFqxN5zuD2ufsMlQUYjT/rZMku7nkoPKprLzhLhhuaHQ
lPZhB/3KLnUhLruqHYyn+592yE4vb6UQPi1bp7ro/fLlsM8j/7VCXCoUJsym
vc+tLEnVSIjjSovSjqrT/XJvV+CYCxFWv4QZQu+/Vg/h1XJrIQy2f7C4Tu9P
Ky99H7vDQnClt4RfmU/B1Ldsd1yIEMPyRhrDqvT6+7c3uFwVwuqhzf4i+nzU
BAq36EYLYVxnvNuNPj+bQ/VXt6QLcYrixDxSorDuWpmsQpUQ1scnO57MoHA2
qv3SjzdCfCv8yZ4jR6HohlD0+L0QDN3v97xlKGjH6nN2fRPiouU2WaYU/f9T
ymqj/ggx6By2OYVBwTmt3dBeYhQpagzkTJLIyBAWa8qNorPxfWPWBAm1bP3M
BrVRRJ4IDQ0epedLQVmQlOEoNuszex/20/O1ukw/zH8UOctznNq6SDyUm5Xz
5+Io3P/LjuB1kLA56KnkEzmKh5Ezh0Y+kbgnWDh4LGUUX/LVTn5pImGsfe2h
ZeUoiBl/rku8InElyf7vecwxLDv2ceuLHHoesksjb0uPYZ8LW2Mkk0SbnoJI
TnEMtey9YvPT6Xn4obaNsWQMPpy1fqbxJOokdaJZ28bo/rZODVwhIX1OTLwo
Ygx5HYVIOkKiqObgKc2YMfTqlizodyRxQL70e1bSGOZETuToHSCRl+fxIj5v
DBdC7RLirUhY/Go5d+G/MRTOmxNaYEjSuTlsMwURWnWKtiyZRUJh5Y733xNE
2K5hqj+jiAeWZLpCXYYILo4zoyfzeHj2e2hPYS79PJbR+5O+F7ncTeoKKRch
trovODSRh3KVPvaiDhEeJZUNLg7hwVEyQtxFeRyZnyfPDG3n4VHPGwN23Djq
etM5SW1chNbMDWxOHccH1/LI7vdc+j51sqo8exxW85wK57/lgmE/xyTi6Tga
hjmnPMu42N3iunvlp3EQjdXHXOO5EL2cdtJTaQIt903e1e/hwizd6N5AzASa
T8602FLbh/C65q8XkydwUvy6q+TzPrwZdFSZnTUBnbJSxYrCPmwzDri+/ukE
+sac5gqT6fsUp9jnYvsELB1sTLNP9cHwn6UWSmp/YLK45MNv1T6sfivJ18/+
A4LdZPDJgQOvgTidhvw/2GP75lCYNQcFqks87Etpf5y4oL6NA21P4nvI2z8Y
OhUYpanFwUoFv/p6zh/crpZ09x5j0+e3L/XgqklMW3zgXXU0G8r9jSbBZZNo
Ndjesr+oFwm3qg5zqibRF7lsl3pWL1R0iwJ3101CfeX9N5/jaPvFFy3/PIln
KsLU2X69mCvuPL9ZNInyM0FHqjf3Yr6ykL9w8xTqGqL1v71hYRkWZde8nsKj
HYMn5zb8RtLbZ2LixxiEhazs2ejkbgz8KPTr92QQvkJzB71r3TAV5Qx2eTOI
DtLXt8G3GyNasT9LfBlECvemXu3ebuyKOf7S7SqDMCvlOk3M6AbTQS204T6D
aP2Zs+pk0C8cH7rAiGExCJHDDYNt1j9h+PeWqYUuYoR7svfarsivMLNvPe3s
LkaYjbEnnBy+Yk/yUdY9TzGikfvJsWrVVxxXvfHfsnNixLRVYTUSH74gaXZX
stYVMSIk1Hu8TPELRuXOGRjkihHV+gG1D251omQy95QlT4yw9+83D/Zqh+YP
+Z4LZ5mEygKpW22FzdjVu7DmvC+TsIpUPPsngP7+oFZneAUyidWz/TlTJs0o
mbCyPxzGJIipaR2r/m2CoeqtVuPbTELeaCdngex7WNgo1MqUMAmGWftpIqsB
nq8VchKHmUSzXsNZudRXyM+d5f70tDhR7dOgc/9pJgK/ObRoXplGEGLNFhc6
mqpOGRrsSLstQQTqbqpsdvxVJUo3duZGTyesjHY3vPUiq5q9k5x8MiWJDEPV
YvEgftV6U/XJr3eliF0GTxLrYyeq6retzyVS/iJ0ruXLLVVnVmc/SVz/K0+a
ONN8LKvzxfTq2Yu1PBwfyBAB09PvKZyTqZ53N6ReebEsUXBLyeNOv1z1/wDh
oxR7
       "]]},
     Annotation[#, "Charting`Private`Tag$16587#5"]& ], 
    TagBox[
     {RGBColor[0.772079, 0.431554, 0.102387], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwl13k8VN/7AHBbZrGNpaIkS6WkSBKF5yQiWUrSjoRKiqQiS1JZSkL2T6KQ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       "]]},
     Annotation[#, "Charting`Private`Tag$16587#6"]& ], 
    TagBox[
     {RGBColor[0.363898, 0.618501, 0.782349], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwl13k8VN/7AHBbZrGNpaIkS6WkSBKF5yQiWUrSjoRKiqQiS1JZSkL2T6KQ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       "]]},
     Annotation[#, "Charting`Private`Tag$16587#7"]& ], 
    TagBox[
     {RGBColor[1, 0.75, 0], AbsoluteThickness[1.6], Opacity[1.], 
      LineBox[CompressedData["
1:eJwllnk8VP/3x8eWJcooIq1SKiIiKZybkFBapWxlKaEsZY8sfSJJslOWlKVk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       "]]},
     Annotation[#, "Charting`Private`Tag$16587#8"]& ], 
    TagBox[
     {RGBColor[0.647624, 0.37816, 0.614037], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwllnk8VP/3x8eWJcooIq1SKiIiKZybkFBapWxlKaEsZY8sfSJJslOWlKVk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       "]]},
     Annotation[#, "Charting`Private`Tag$16587#9"]& ], 
    TagBox[
     {RGBColor[0.571589, 0.586483, 0.], AbsoluteThickness[1.6], Opacity[1.], 
      LineBox[CompressedData["
1:eJwll3k8lN37x21lCzNjSUKb5FFpI0tynYQkqVSUhCRJnkKRLUk9SEVoEYUk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       "]]},
     Annotation[#, "Charting`Private`Tag$16587#10"]& ], 
    TagBox[
     {RGBColor[0.915, 0.3325, 0.2125], AbsoluteThickness[1.6], Opacity[1.], 
      LineBox[CompressedData["
1:eJwll3k8lN37x21lCzNjSUKb5FFpI0tynYQkqVSUhCRJnkKRLUk9SEVoEYUk
KUnZSU4pa5uQJWWdubOPdcyM8D2/1++v83q/7rNen891nXMvcz5rfUJIQEDg
q6CAwP+1wljia4/OZSNO2f+3K/vKtqjGOcK9/OZxZdLyX61zaY09C9538kwa
ScuSc+MWxF6CkGfvA1JJ+9PsavmT2GhQuZzyeT9pfzjGrnoYmwybTaUOHIxJ
BmuPRT/jY7NBG/Pf+t/Mhpgx+9y7sRj05Z+ZqARj2FJhIWF8rg4U3r41lTCt
A88Aq2O5ni0gm/ZBu7S1Gf4tOhEltKITOuyWfzMfbIfG3p3iT52Z8GJ69HCF
WA9EruMIFBzuhbGJ/UIWdAq8VlffefdkEHQ83upncnuBeYIZklIwCOEO1at0
hPvAJkXAI6RqEJLGdJcVSfWBgby+MeobBLv3dzSfLe8Doblnw3jNECiMDJnq
WvZBbP31HTh3CN4JhCsJJvVBjv8e3tv3w3DZ9WKwrmE/8I+ffvn7zAg8Gmro
vOc8AE70cb9S3xG4Pu/phmL3AagoC9ieGDwC1cehs8F7AG4timw5FDUC3qV9
VpOhA7DqW4ZQY9YI6Fx8vKU3dQAOGFA2tYMjkM4afHyjawBe0o7NFbiPwri9
WXT54UGQK+utueM9Cv1XkwYkjw2C/2nP2+cDRkE9ZYW7ldsgmFRe+mdj5CjY
NWVXlvkOQltg0v6sZ6PwKEryi2XcIIj9aXv6uHcUDk2ujFL+NAjOb2323nId
g8vbv2tf0hmCjQWKjEVnx6B97HzNOcMhEMr+2fDowhj8/luxwGn7EKSmONjm
RoxBqWjsvSX7hqD7iqtD0/MxOLPMJNzAYwicLXw9lNljsEfVc3l7CuHmOxEZ
F8ZBOT3I6ZvwMGyss7XYEDIOPqU7NQrEh0GoZtGCkohx2Bjg7HJbZhhSSx5G
f7o/DotOft6ou3gYuh8+uTv8ZhzEOpz48huHwdklP01bYAIWrQj/tNlhGI6P
Nr57FzEB8zf5vuRnD4NTwC3bolsT8B8jVScwbxjshS2Hs+MnwKu2ZclE0TDY
yH9YnJwxAa87eYrfiI7m+q99L1ZPQOvJgEv/NAyD1uWbawzEJsF97ep1ZyeG
QVNi54cNtElIXq/l6sMdhlVxInb/KE7CkI8L+9zfYVj6JDBcUWMSBjwvTBwW
YYNszaluzo5J2Pqan1UjywYuzSw+N3wS5H1aJHQ3sGHivuC6zOhJ0LcNGXuv
zYbR5W8rUu9NQjTntIqpHhv6tbXHY55OgmD6HX1tYMPvQ8utPKsmYbnUvnP5
lmwoT5kVXivKgRLxF5u2u7Kh7J+SBDUZDlj1ugzsO8WGNzk+G5QXcqC252jr
IQ825H0cdJBcxYHz7YyDe7zZ8LT3Z3GfGQcaJcUK2y+y4cb6wrPpYRyIE/YJ
D4tjQ+3GZsonigM7Y3U9Je+yQUxn6qjpXQ6cPrW9PiKeDVf1dS2ZTziw4PXP
OY+HbAg0LtRYXsEBhWRq5Gc6G4pMmpNHP3PgUlNF3IpnbOCYTSm8b+SAbZJL
pksmG7x36c5zYnJgm0HZ5rpsNrgfKOx6KDwFVxYeyLYsYkOGTfOhfyWnoPL5
nb5DJWygDk19M5SdAqNTIbePlrLh2FHdsrblU/A2xM1g7zs2HHItTFhkPAXp
/GvFP6vYsMOvcP+dkCmI2aO34uoPst+A5lqXiCnoab20cWEziV/Q1DbtW1Pw
uyIpM7WFDUaXddc3JE/Bqbyh1tQ2NmyOLFxAx1PwabGQinkXG87faL7SWTkF
HzdqeiV1syEnaoqf/XUKFr45s2aohw1r43T7rNqn4NJKRvM5ig1qDworbsxM
wS+z6xMrB9jgnNRsaD+PC+sV9/vDIBtSUqZyV0txwfbJiPO+ITYoP9FNrVXm
An3Fi+MObDbYPbVdlKDGhQ5dq4DDI2yIf3bh1qk1XJDc93XCcpT462VhsJgh
F2Z/XZVTGWfD3lfNk83bucAUsirmEY7KmfJ4uosLcXFK779OsEGiUPeI2REu
BDlPcY9x2GBebFsvf5wL3cwMjaVTbAh7c2Eny50LgXYpJU2Ehd4V6l4N4ILh
60KRtTw2PJdipM+EcsGCbs5pJWx9xEPuwnUumL74wr7IZwM/ozJ0JI4LGmcW
jypOs+ExZ+noqQdcyKyZz39O2NIk0LEnjQvmRScltP8S/8f8+GKfxYXdJYrL
8wibrI18vqeMC/4Pulzvz7BhMICpWFNJ4rH0Tdws4dvVRuHG37jAmD1ZZTfL
BkOF+5Nvmrkwcfib4EvCrOPjx3U6uXCs/acxl3DU6931L3vJ/t76RurPET3n
niKNUS60Zce0eBFutxTKfsTjQhZHee0jwmEJ9iqLhXjw6vCCiCrCWr0F129L
8ABp2PQxCTfp0PlSsjzQ1R/fyyMcfOW0W/hiHnj6nHUUEhiBVd8rmgTUeBAT
c/2+MOE61aWmAWvIfKu+2ggQ9vMIyB3X5kGSi5fWKBm/tKRx2b9beRDUkZjf
QrhadN0typQHBh9XbC8k7Hnw2qyjFQ/eJMk23yCs+LjHo9WGBwmhfl6HCb8b
2dpm7cgDWUlnhgrhU0bxOz+f5MGKI93FzeT8jBtjhaaePDitIu12jXBJq6U6
9uPBwat/lTcSdl719LbeZR5wd1a1fCfxlfARFM65Rsa/ikx0I5xTfsRrdSwP
nEJOnOAQfexoBR1pCTwYkfTfHEhYyIFmpfqYB7Wr+6SniL6Zme6l9zJ5EI9+
DZ8ifID3UZOex4PCjYFNDcQff82W3I8s5cFa79EKbcKW3Q0+F7/wIBpU37Zx
iR/WaTE5P3jwab9exTLCDy5GWHu2k/Xej/xwIH4cUty67jibB/NuLGGUTRJ9
96T3mtP5kPtg81/aGNH3oYBt+SI+rLk1vkeG5Ed7v13FluV8GHe0eSlC8mdd
mEyq1iY+ZB7bdqOR5Ftdqd8RuYN8uLz4yQ+xPjb4STTU3DzKBxmPC+H4D9Hn
0Fo9UVc+qA7Gm/1L8tlzvEuO78sHGw2r4SyS73TNXV874vkQVpk9/OE3qU+i
yfTqFD5cM1663uoXiTdr7MCrDD6ktM97XveTDS6PEtpCivjwvveFeRmpP0WK
/b3LWvjwNMTQ0PA7G25ytq6R6OTDuwYly4hvRJ/GmLNjf/jwixl/7/MXNkje
0ueUT/Ehumdtz9ZaNjiIXhN2WTgN+z7qH/5QzoZNrF9mlkumYeXCcOvvpB6K
fVgfqb1qGpDiouvNZUTP4BbaPN1pWM0SLP1M6uk8zirVdJtp2PGBttouhw0v
mJV6vXemwVqjIF8whQ2Xy5WC6h5OQ+Oz1d1xpL7bpJzBRU+m4YNIko1qIhsE
7BXMruVPgza/b5EyuR/2N5zYr/ljGpTMkxa/uU7qwXuRMx5yf2FvdvbDcB9S
b5KNH4/E/oW0B1UxjtvZEF5d9zs08S+kXA3tzCH3W+Wog6J82l/4jyrVm9nC
BlOTwJv6+X9BtF9Q4gK5H437ci+ENv+F89aJVnNqJP83rbSUU56Bs69FHI+T
+3Z9leik7pMZUHMMVQ4tHYazI3fW1WbNwNEL33qKCofh5SI1d/uCGeAvWvyL
yhmGtR6oI6RqBoxfW5zQeEbud7p/TU3fDDhl9Qga3xkGtSP9D49ozUKHiEZm
3elhWMj+bHapcBb+bdx/0ZUxDPEx+FgfnoU/65u7Hi0YBkXtnKD91bPgpDnL
bZxP2P9ezqrWWVBSLzFdPj0ESsLOqnX8WRDPEg4/3DMEqgunJpcazYGot/Uy
w5whUIdlT8o/zsF399djv3cOQUJViaDwKQGkWGRzbcZpEEY6X/mzPQSQiBH/
Qgl5/+3gp4+2eQqghknjeE/rQZhYE9eV5yeAHL3+nK/ePghWsaffu0YIoIHw
hjp19UEQOqp8ufapAOJm+2Um9w3A6bGLArGUAIrnKM2PPj0Ahirb5pa6CKLu
3oA79Uf6wdy+0dvZTRB96T/R9Y91PxxIPEk99hBE7/+79t7fvB9OL4r6ou4j
iCw/vt4prNMPCfJtiWvCBNHBmavVb6X6gSvlo6eXIYjUn5+cq3/bB3mzGV57
BgURUntRFqvYB6s7acyL54VQtUH7LL34D2RlMNzyvYVRh0vQgz/dTAhqP9qw
OkwEMRON+Ph8F3gZ6u1Kuj0PnZVwv1oZ1wb8ZBPngVvzEWdyNpi5rxHqPBOc
LqSKIpWyqvevzKtBf8fy2d+PxNAmTuSq9H9fQ42pfgZ6II5ebHNm443P8ZPX
9/W7MyVQxYmYU28qK7H8ijXuDs8kkaGqelfh43pcLygWuqh0AcpUf91qMdGK
88XOpdfVSKFb1wwOt63rxFTQ5aGyL1Lowb2wGJ5BJ1YcjdbO+i6F6N77h2hm
nTio9UX5tVYppC1XyNG078Qmz6l24z4ppLhD47FkRCeu32W3MF9MGr26xGf7
t3fikahtEfd3SCNqUcCB9v+68HLhvd/Cd0mjYjlOm9ytLnzggoOC7x5p1HJf
/e32hC5c5BiYZm0rjep1W7wjX3bhS+vz30melEZSQcc4JU1dWLpeg3cxTBrx
X1zJSl3ZjdfI09ydK6SRWZXvT4e33Vg2+82LJzXSaNJ5Jt6uqhvzzU+ye79I
o7+iJY6W37txdVDZ+bNN0shr6GgPndWNXZgel4L+SKNly4y/r1jQgx/m1ty+
Ky6DPojIZx451IOlra/g2t0yiJmwLft3bw+eHNASkraWQbeGGoKujfbgX//9
NNlnI4NcP2NdTX4Pfl68obbZQQZtaTPeZyHJxGbLOhuZZ2VQk9hJWZG1TBw8
Ytg/GyOD0kxEaw+eYWJ2FEduU5MMcpS88W19LxMPjqiWr/0pg4JG7jYPDTNx
v/WOsxrtMmgu+rhOyiQTMxXia1QoGeRyglXPFGLhn0n6wWIcGbTZzLB4UJmF
nW3LxoclaEjv3IjJiBULH4uwthhcQEOaB+smZg+wsFMxldInTUMSVkcDhY6w
8NHFMlZMBg2lR+kN/nFl4UMdjhmtSjQ0LasbsDqYhXefFDz6UZOG1Jd0qEU9
Z2HL+Du579fQkJup/1kqm4Utav6RwFo0JKcyKLUpn4XNV1sXFm+koe0slZXP
MAsbs1Pp2QY0xNdZ0iDayMJ6F0wq71vQkFBsdkM4n4V1M1qU71nSkMZlrTPL
5lh4c6vHudtWNGTXlP/jpTCFN225szTamoYMN8b3pS2gsNYcK+CqHQ1Vejdt
mlGh8Irw8HVn3Wlo4Q/XtzZGFPZu0g529qChOFvEkTem8LuV3Z8PnqGhROQ/
Um1KYYePhu6G3jS0obdIVGI3hRMEx9LEA2hIjGfdPGVH4b69yeN/A2moeL7G
hgMOFNZLsTQeuUhD+x5Ziacdo3CT0dOOpsskfqLFDFU3CjOC7JXSrtFQmsva
BwHnKXzsk/ipe9dpqNWrme91gcKvlAoLI2/SkFFFbpx9AIWtiukHvWLIeq9T
9kmGUDiSUxltdJ+GfJMfLfgaSeFW0/PtGxJpqCTKepfDTQpr3Fm2duVDGvrM
/xvcFU3hyk1BtZKPaKgowjL13W0KC3ltmNeaQUOpVQY9nQ8pvO9d+/7Pz2mo
/9KWRtEUCqfI3EjFL4g+qm3nlqVS2OglBemvaEihyytxTTqFb87ERd3PoaHq
kgS6agaFf1lu+30jj4ZM2ioYQs8pHDCQGHCuiIbMfaxjH2VRuMZgZ41rCQ3V
fcOz9tkUVozkLLQrpSGkuaNe4jWFCzT25aN3RL/psMiteRQeOzF/RKqahtTM
xrbNFlN4W36ukWAtDVG7/Pp2vaHwLZFjNyc+0VCpq1P29VKi7+M3mm3faGh+
/UOvrjIKXxxz8//6nYbCdCOPTGEKf96mUP2+gaxXPx/m3lHYvdPzREYzOU/b
0y/McgoXr1PNS2wl8bLa4lr+gcJilz4JRbfRUD3XsCHmI4Vtv/rtC/1NQwE5
tpL7KyicrqKe4tNBQ4qGG+bNr6TwpEfDsFsXDSnruRc+J2xSGrLVvoeG7qon
KW6ronCcpNaNPSyi/7HjS2oId9u1/TT+Q0MM+V3lxtUUXrDV9qlTHw154lce
BYSJ7c8FD9BQRJ2V9KIa4j/BPejBEDm/lnCiO+GIntoFJWyid0Da/EzCORVm
rc2jNLRZVMj0J+FfT8ufTI6TfKvv2cklPD/SyFuWQ0PWwRLi82opvM6jxGgD
l4aWWqzzFSB8yGqz5B4+iYeEyH/9pH/o+pxmj780ZLNs0z8fCL9gaKVFztKQ
kr+jTSThpolnnhkCdGQUqCaACAs0r9xaKURHlJiCEpPs/5/iR+JMETpqOf/u
ni9h60SVJkFROlIPzPCYIucPung/dYk4HV3V33XDlXC6o/zZrZJ0xNFQ7f9A
4vdtW8yWI1J0pCkf7S9DmLtCSsxfho7q5EW0dpL4L59/rfEunY6WhrXxPYk+
lr0ij/Jk6aho9nRDGNHPpzbk33p5Oqq2FMmMJPpWR/nNl1aiI2N/JzV7ov+Y
50T9amU6MihMePEP8cfi/Z7JO1XpqNG/RoD1lsJnFrrp/becjoTUElrViN/i
eT0ij9XoKKzL2+QZ8WN5m+P3d+p0VIuzdiwuorB8iq37X006cpVx7Kki/jUK
bdistJaOTH58OiaUS2E3lz3CeuvoyO9guIkm8Xupxo4H5zaR9e0uChmT/KAk
PrjF6NBRcKHHhw2ZFJYZMtLJ1iXn85TLk35GYefXm7/2b6GjiHOJ7Og0Ct+I
y0kQM6KjSuWhJdokP/N9tE6qIzqy+dJmUZFM/GugLuBsQkdunopHXiZQ+GW5
/MZWSzqKnx0YvE/qQUtazCzHio5cprYGpN2gsGC41Ce5fXRUf8zxbuI1Ch/Y
Nc9l70Fy/tH/TPZcofB0w8SdqqN09PlEFrfWh8JqBZ7OLEc6mpgQuqjnTepT
/KCWsDMdxSprLY89Q+FUe2aVkSuJf5jjPfGTFDZnNfDyz9CRfWfWE1Fbkp+r
owKzPemIGRq3W2U/8a+X+UyGNx39mlQzX7aH6DFbKvDAl44sr68TnTCj8LBC
umhoMB2VGN5z+6BD4dvmfvJWUXREO8cNnpMh9SVq470dt+ioP/t524QEhWcb
BxW3xdKRYrvDt+Z5FD557Jiy9l06OnCZuct1moUNAixWKCXRkeekm3kai4U7
M5U3UFl0tHn0+8v7BSwsP9aU05FNRxIanV+dX5H7Si9Gu/U1Hb0aZZYrkvss
9+M8vc/5dJS+QnjS4iELh/0eNsp5S/avtGFFVSgLr5F5bxn8hY6c0c4EWQsW
9vM+4aYwREeDKqu7U2uYOGLX8EkDNomHw/iFDe+Y+J7ahZMOo+Q867SSnhYw
cUFThGv6JPFjLLK1eMzE4wYvXDbP0pFYoWL8yUAmPiM87mQjw0Af/e5Ij6kz
8cVfgU4BdAYSk/W6OrqYiW/kizglyTLQ0oKd3s00Js48qeBILWSgxpKlZ2zI
e6P3k/5R36UMFJHXNaj6uQcfvx1y+O4GBnoRp0urde/B3v+KHy7ZxECe4gUh
Gg49ONQs9lC7Dpnvp4yJx74enMJ9bKtuwEBBLPB7rNuD2+2rDhYYM1DRmflh
X4V68KGV0tZN+xnIUE0qbP7tbmxVkGih4MtAlnazOT6PurDbuPOcvB8Dnd9i
pXk6tgtfWa+ZJx/AQHujbbbuuELec8+LVOSDGcgtIXM8x4W8/5J/jMiGMZBc
8uNaG/UuzAmXuUe/y0CvrMpM36d14qTDV3oWFDBQRsg+i72LO3DRXYv4BUUM
5DfZmZzMaccNDfTdC0oYqPdu2vfC7+1YzCqlQLKMgWitc7rG4e3Y2/jtNYlK
Bqo2FpR+w/6NzVZPrRNrYqD17asClQt+4eG/7kHCHLI/3+quOwt/4sOHdv3D
myLz9ykO3x5sxR9zVzcN8xjIqTPd3e59K77vPrju5wzRIyJVVc+9FZu0/Nvz
ap4s8nsett+guAUn5npaOMjLolcDQk/1LJuxubuvYrG2LPLU9tOWMm3EuRU2
FS83yyK31M/l0YxGrLpM1ztNTxaZb6N3NnQ04PHmqU/RhrJob4WiWop/A04y
9b/kaiKLevuzDpg8r8cTS4Mo2QOkv0Sw9L25Ovyo+XLemXOy6N0vcxQ4Voup
ivUdUT6yyMlY6sHuc7V4TV6HePYFWSSQlh0QMl6DC25tdWQHyiJkhXnzxqrx
5508cc+rsqjz2PWgK38qMfeNp6PXHTLfi5vHe3LLsVWKo8T5QsIeW+cmH+bi
21HSOreLyfiLKzomfXJwa9Bbx7w3siikRXn+fcvX2OXw4vwJTHiP4pXIgSzs
z2h29KkmfMby96azaTjtqlW+byvZz6umktPyDpjvttXJf5p8v3+zQ2RRHli8
0UQ+M2R+/UN339jmQ6KU4lKvOdJ/rX1A2b0CMMwZ63ATlkMhovo7XiwuhuDp
p46HJOWQwGvpK2hTGQhHMRx1F8sh9M+UkPi+j7Ag98/RSQM5tLQ8d7+t8Tew
n/dj66gh4VDFyv1T3yDLtlxlyIjwxL6zoTZ1YPX3wW+msRzamy7ks13qO9wy
tT7aaEHmj/7dJ3mpHuRaSu1z7eTQSNHL7MFzP0BlJuaIVwDZT7GOT0ZaG5h3
7y6+FySHbk26LLoo+wvOV4kvLAuWQ51b+GsqQn9BbczleokrZH7t0MlXzr/B
V91rZ9p1wivOOAlodEDdnr26zQ/kkLmV1IITLl0QmiotuxXLoYhtTjuLN7Ig
K7zW8/h7OcQteLAq24sFLR5hX699kENFdt93Ml+xQEt39lpTlRwSq8+Uk1pP
QdunIQHPOjmUcvY56+iGP6A9+Xk4tYsw7wNnJeoDasf1WjEReSQwN+P8OHoI
nHc5LV05Xx6lGNh/ifkxBL+tdHy3iZHvndtlPywehsaDHcsCFsijTu6b8eGM
YSg/vsl/QI703x511KuSDQ8vta36ulIecXcsm1spOgoHClf/F7dDHum9zH5h
f2ocPqh/BtXr8shP6Omzvw+4YBHVYaFwUx45tdTYLK/kQt3k2EHpaHnU6+DT
5c7mQvvHRR6zsfJITEBm2MWYB1znk/HtCfIootI7eK6PB2uShUaTnsuj+HlF
oT0wDXcX6qcuqZVH1VHJeQzRWXAXSxdZJq6ARJ5d37VPRAh9Eoq4uV1SAQl8
VYypWCKE1sycUnCVUkC3lXYvsd4ihNijazUy6Qqo5aT60TxvIXS+LX+XjpIC
MjneeDC5WwhdfFkRu3O1Airizy1ZUiWMbh1gLfXerYDSjjlN73g8DxWmqG39
EKOA5HxPLw58IY7U5kwC38cpoBFJE0nrz+Lo1tETxfiOAqIpXnE1HhRHbkrp
OqX3FVCndl3a2TUSSOn2Kq38Rwqo199LczZLAgWFay55+pp8jwz+ys+XRMZn
1gte/07Gr95zc4T8d5cwTEJH2xTQhlVb/xxOkEb/A8iod+I=
       "]]},
     Annotation[#, "Charting`Private`Tag$16587#11"]& ], 
    TagBox[
     {RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
      AbsoluteThickness[1.6], Opacity[1.], LineBox[CompressedData["
1:eJwll3lczN/3x6eFFqGpmWaytaAsKSElca6kQgolbconRZI2SwnJVoSkQqtC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       "]]},
     Annotation[#, "Charting`Private`Tag$16587#12"]& ], 
    TagBox[
     {RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
      AbsoluteThickness[1.6], Opacity[1.], LineBox[CompressedData["
1:eJwll3lczN/3x6eFFqGpmWaytaAsKSElca6kQgolbconRZI2SwnJVoSkQqtC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       "]]},
     Annotation[#, "Charting`Private`Tag$16587#13"]& ], 
    TagBox[
     {RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
      AbsoluteThickness[1.6], Opacity[1.], LineBox[CompressedData["
1:eJwll3k81N/3x23ZimbeMxMSSbQqKkLh3HxKEtqIoki7kFRCUlq0S6hoI2Up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       "]]},
     Annotation[#, "Charting`Private`Tag$16587#14"]& ], 
    TagBox[
     {RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
      AbsoluteThickness[1.6], Opacity[1.], LineBox[CompressedData["
1:eJwll3k81N/3x23ZimbeMxMSSbQqKkLh3HxKEtqIoki7kFRCUlq0S6hoI2Up
peyU3CJFSYrsZEuWmXlbx4z1d7+P31/n8Xy8Z97nnvM6y33PcTu6db+EmJhY
jriY2P+sJJYvazMINhPk/7/V7spfrR7hAvcyqwdmETvyRndfbfhR8LmTsbaS
2L/sQ8Ks8LNw7vnHgDhi6ywuFsSH3wK14NjSbcT+dgmf/yg8BlauU7Czvx0D
Wz1U6qLCX4M+Hnnvf/M13O53Tr8bjsGY83ytWhCG1UVW8ubHy+Fi3vt18uvK
wTvAdk+6dw1knyrUz6utBs+c/aESc5tBO1n9hyW3CSo7N8glurVDT0ftjiLZ
NrimKxDL2tEJETIvxK2YHXBscfGdD/FcYPt/MUgWdkL7/vZzsVlceHs6Z66B
ZBdsjxXzOPeFC/NCFNRyFLpgFcfYHHVx4dUB/XnPNbtAYvI5H+vwQEjPWGNo
3QXhv66vx+k8WOAdxxZ/3AVp/ptE7z/yQbWz+qShSTeM7D2S0ujVCylmnWX3
3HrAlTngl+fbC80LnGfnuvdAUX7Afw+CeqEtNOJ7hU8PhKlcq3EM7QVfP9/V
Q+d7YP6PJInKV72gf+7avM64HrBb1bH9K7cXBp9oX7/R0gMpjD2TWe598HHI
zrNgB4krv7Pkjk8fNM2VLJm6hwv+R7wjTwT0gdaaegvbQ1xY+/nswuXX+gCb
SsXl+3Kh/vTjba+e90HUguPx1hFckP1Xn/i0sw8kqxRdZ33jgtv77ZvDDvTD
Bd0PgiADHizPUqZUjvaDV5XWteMmPJB4XVfx5FQ/PJBdVuryHw/iYnc7pF/p
B6XIPXazt/Cg9cKB3VUv+uHNm3CzVR48cLPy9ZhF94PN5TPfG2MJV9+5knRq
ADwOmPDKJPmwvNzBatm5Aejk1qZlyvFBokRl2tsrA3A7IJcbMZ0PcW8f3foW
PQD8mxFZK1X50Poo/i7/3QAEaoae4Czng9u+zGf6YoOQkndcb+VuPuztq/zw
4cogzO3x/CN6zQfXgDCHnLBBuGAwZ29ABh+cJa35r6MGIbzy54aBHD5s5xSq
xiQNgq33+9VlREdL41TfM8WDoBi2IGJBBR+WBt/UWSU7BF42NXO8BvmwSH5D
4TLGELxTPG53QsiH+RFSOxcqD4HzVr1anzE+aMSfvqy8YAg8tNV/O0rRwCo5
3CpYPwTuyhdPF7NoEDIsotIvD0F4XHyKwTIaBqPFdZNvDcGpobywD/o09Gm+
L4q7NwROuyWz/jOioVtff+B24hCsvvf083KgodFR09b7yxBM6ll2plvTUBA7
IblERgCuodon1hygIX/h2/ta0wWwy7lFa/NhGt6lnVw2S0kAMnThVAcPGjI+
cXdPnS+AzZ8m/Gx8aEjsrMvtshDAihkf8xrO0HBDL/toQogAjlef23gxgoav
y6s7ToYKIME2Y7HcXRpkDYZ3rbsrAJdNrEshUTRcNDa0bo8XgJGxINb9EQ2n
zbMXaBYJYP0aLc+aBBpy1lbH9JUSf/KB0nOe0yCwGJ7xsVIA75/4sN2SafDZ
aDjFtZ34F1e+8f01De522S2PJIfhyNMX9RtyaEjaXu3oOXUYvh7ZNnX7Wxo6
HId/mLCGIck+OHlnHg17dhnm12sOwzle8GqbDzQ4Hsi+r2I+DCffMW5Wf6Fh
vV/2tjvnhsHllFbkud/kvAHVX/ddGYaOg853WdUkf4HDa/TDhoFhhiRiamgw
CzbUq4gZhtQLkZyYehpWXsuexsTDsFQpQmNtCw0nblRfaP48DAl6aw7cb6Uh
LXR45HXZMFjKNVBdbTQsiTDssm0aBvrL/ZijHTRoPcwuujE+DOZ3h4Lm9NDg
9rjaxHmKEFyUswZWcWmIjR1OX6wghHWU8ndrHg2z4g3jvs4SQpHh+5c7aBp2
Jjqo3NcSAnfzhTS7Xhqinp8KO6wjBMn3vaqWfaS+UrKDZE2E8M6pXll5gIbN
b6qHqv8TwvSJruRBwqFpwx6JG4XQ+qvgSckgDfLZhk4WTkLY1imX6SygwTLX
4RdnrxDOz1L+NXOYhpB3pzb8dReCs7velp+EJT5kG14MEIL2sooT80U0vFCg
EsbPC+H5k9lbKglvdfJgn7ouhAM3lQz8RmgYSfp8vjdCCHjkhgZrlIanAo2+
ww+F4HTCjhVP2HrtaZe2Z+R9cusUlo6R+r/9+7vzKyE4WhspphBeu+Tai035
Qij7EK0VMU4DN6BdueSzEK6kfDEWEo4sNrts/kMIyYWn7O0maDCZET30rloI
CQvDTiUS/rt3YK9BsxA8QkUxfYRDU21+pXQKIUQrpmz5JNFzMhEt6BMC66mX
5BHCTdYSr5+IhFC4ztHsPuGQ+85qqhIioEttz34gvLQz63qkvAiun1n/uZFw
lQFzRIElAuM5q1j9hIMuHDl0WVUEK6XnHBgnPP9nUZWYlgj8JoX5k4TL1TXW
BeiI4Pa+j2oiwn4eAekD+iIoYgae7yKs8bZyjqepCKQOLeGVEy6W0Q3rWCeC
FuuGXa8Je9tfnXCxFUHkovDKi4SVn7Z51G4XgUzvzi1bCH/oNa3f6iKCVMa6
Sjbhw2ZRG0oPiiD34p5dP0j81I3+7HXeIvheXMg9R/htrfU87CcCs6bg8wsJ
u81PjDQKFkGTVYZ6Ccmv/ElxybSrIpii4vvRhXBagdOxxeEiuFXd7s4j+uxk
ZP15dl8ExdEaqj6EJXYzbNWfisBzeOMvHtE3Odk9716yCB5NuxHmSthO9GkR
M0MEP/xlt38l9TFmMTv6Wp4IPu3t0VxM2Lq14uSZ7yKwqYqu+Ckk9aC7tF3w
WwTBpp+zlQg/PHNlq3cTeV/TzGd2pB55yqa6e2kRJBvNvJs+RPTdlNBpyRyB
UMVpHVP6ib6PxBwKVEbgjrskJUX6o6l7Z9FqzRF4ZjTbUkT6STdketzSFSOw
Y1p/RTHpt/I8Pye2/Qg0nvzlM9ZJ9JGvKLm5awQkXj0Xpv0j+jguMZI5MAIv
Pcyvu5J+9h5oYY/4joBiycqaWNLvzEUby/5EjYDLrsWzshrJfJKJYRbHjoBD
v5UeaiD5/ttv9yZpBKa0OQYW1NGw78n9+nM5I1CdkPX+NZk/OcrdnXNqRkCm
eG6vzk8abgpMdeSbR6BydGuZ3w+iT+Xto/3/RiD2xq1/ed9pmBpmLCgYHoFX
Du2lS77SsFvmquQ+pVHY+X3T0bQCGlb8bbCwnj0KHrW6yz+QeShbqHdNf/4o
aGRmrvicT/QMqmFMMRyF6zOeDr4l83SKYL56wvZRiNQSC1yfRsPL9s9GnXdG
YXHI7xm8GBqCC2YGlj8ahQykJXGWzPftsV44J34Uls/K1Jd7QIOY8wyLq5mj
ULxX2kea7IdtFfu3Lfo9CnoSqbufXSfz4KOUlwd7DIRn4sK8TpJ5E2P+tDd8
DLrNT5uu+Y+Gy8XljecfjMHpOv78SLLfPvftVuY8G4MLhpkzm1bTsG7t6ZvG
mWMQd/CsmgPZj+Zd6afOV49BRtyZrEYt0v8rtK3Zs8bh4eiS5WZk3+p9kRky
jB8HA6tZ2XZ5fDjae0f366tx4JSX865l8yFFRcvdOWsc4pe2bstJ48MSD/Tn
3JdxMNJPTBcmkf3O9C8p6RoHDdbMrul3+KDl1P3IaekEdBR1eEUf4YMSXWpx
NnuC3AOYF+dSfIi6jfd04QlINbijvnsaH5T10wK3FU8A70zk4TBpwv730ubX
TsAcJx+lhhEezJR0Uy8fmYCAm0vEGG08UFcaHtIwmwRndUP/nlQezIM58QWf
JkF6oF7tzAYe3P/yVlzysBiK/mZqfNyVC73Nb/xpDzF0XAflLSX3v/UjCX31
3mIo9PdFz7YtXBjUiWjJ8BNDud71e4z+44Jt+JGPB66IIfPrFoVh2lyQ2DUr
+GuiGLqnnjky1tkDR/rPiIV3iCFLSRX1cnI/NVFbM6mxTxxZDGVe/r6zGyyd
K33cDomjadcfcDS3dIPdg4MdTz3EkfFi+WVH13fDEZXQ7/NOkucrzqoOrOiG
+5z6Bzoh4igped60uGndIFQ4aWSUJI6+5q8qe5zXBRkTScc2ccVRiV9B+Xyl
LljczGg/c0ICXUhdZa+e/Q9eJVGHMn0kUdaXgU/H/rRDYNOuisUhUkhPMW7T
Ja8WOGZitPFx5BQ0M6sixSSoHkZi1rr1hEmjFo0Gl7qllVDufd/1VJwMYsjM
nsyp/ALG6zUnGp/IIsbCPSpTJN5AyTrjJPRQDpWrlARJXk3B8anRxq3J8miM
U5QpOFmMOXN13Hc/n4ou9w/srGirwL/EZc+r5E1D5U9OPEyorseZsscTyksU
0K3EKtfIyBasw2G4uxUpok03U41/ZrdjOlTAXlE1HZWLTpetLfyHub3qBUvq
piNFd6MXDd//4e6t648uaJqObPRzb3rV/MPtM6JK1DqmI8ONCnvO8f7husfG
QbKC6SgizpPrpNSJ3RzyB/jyDLRj0TuD3sOd2Oag+K5PixjIYv2sygD5Ljz3
8mXdo+4MlC+z4nGIUTf2qdIPcvNgIM+43yt3r+nGH7RbS+29GKjQk39c16ob
7/5k4m7iw0At99x/5Tt14/vi/c/kAhjod+3ilrCgbkwFOs98dpWB+Ad7bMUK
u7HEsWVTapMYSDg7WTBm0YO3fGjaVvqCgVojHcukNvXg2Ok34vBLBtplP09K
2qEHm6V0QMIbBmJtfBU8eKAHB/Q8CDiew0CmuQFXg0N6cP9+6V6FYgZq3vFb
uONTD27dWV9n/o/4UxdNDq3i4mmmDomuXQxk7sSr+mjOxQazK44H9TCQ3oe8
25esuPhK29dpb2kGmvDuSxrcwcW6Hm/NlgkJ+xgoH/Pj4sAz0XGz5ZjopcWs
yuZ0LubEOriPLWKiC02f+Ne0eNjsfMXKmUuYSPrcxA3bxTx8aN8mSSNdJprT
/qhAbjkP5y1Y//D4CibyyBV0HwAedktdWda9mokMwn72vtvBwykFnOW11kxU
ayTTWHaDhy3/VogyvcjvPS0GrnB5+Mzi0NOvvZno9+eAH7V9PJx2zHI8yYeJ
pJJvqs0d5mHViTyxh75MdL/wqWyMOB/zZyTInA9iolg9He7qGXwcaenHsQ1l
omqzen9ZMz5uTp61rOMVE/0QUw1quczHnP6qtD+vmSjUV/aE6Q0+tjK6rV+b
ykTiG0eTbofxcfqnKUalmUwUpcYr0Yzm45BGvlnaeybKebsk/9//PmWnf7QO
+s5E837maI+W8LGfz/5DM3hMtM9le7OpFI2vbOQfXEUzUUTwQ7N/MjS+p3Xq
4O4+Jkow3W51eSqNs6quHEgYYqJN8zfsTaZoPLDq5b6VE0zUtOzGkQsaNPaS
HHDdPp1Chx/I7z62isZnGk67BjApNMfAruSiKY1vZEq5PmZRaPGag19CEY2T
D85w6VCiUMFx/5MhFjTu/Ga8y1eDQjqRUR5SW2m8N/LcjrvLKPSwwvOA8UEa
+3jK7Xi7gkKDKldR5mEan7cId2wyoFBu7uHI+R40jhU+dZi3ikKxyOcp7U3j
Jucv9lnmFKq++05fIYDGPIPN9nVrKbQxiZluEkjjMcVauwkLCi25sDbGLYjG
qh+7t1lspNBHKfd3t8/T2FFbcWvVNgo1/NGpC7xG40MTd7eM2FPovrDqscsN
Gp+qnr1F3ZFC9qU1RUahNL57ddnmA84U8l5kZlB2m8YVPDtbwT4KBQh2+VyK
onHr50abmQcpFHjsqqbqfRr3xxywMTtMocjyzoWJD2jM2OpnHeJJodXx343i
HtPYNuuB1QxfCrlOWi3Tekb8D7hNcvwo9OpyiJRDPI0v6C3K4ARQyPOpnVtw
Ao1zXuSocYIoFKHunJuXRONf/87+Yp8j+Rg79ub7cxK/1vrL7PMUenm4YknV
CxprxvzuZYVQaHqNafb3lzQ2aXgYz7pCofzxxR/zXtHYQWXfTtY1kn+hrs3T
FKJfRH8hFUoh2nfTv+1vaJxQnutHhVFo1zPHgbmpNP6oELyECqeQ+sjWM52E
BZen32PepZCstISMYzqJr6hqIzOKQpOlL6UkM2i8WOKxGPM+hV7U6QfGE7aA
/ZmMhxR69OOeB2TS2DVQx53xmEJq2yorywkH5A6oM2JJvlnd6TuyaHxH8LZi
ehyFlhbWytYR/uq9wXR6AoUMqm0ZH7Np3P6K0a+YRCGFjLoP83NoPNldnaD4
gkJ13jZtlwjPXBDjpPiSQnalL33rCevvP8BQTKGQ4OKk/4Jckv+4JUUKbyjE
tbfhehA+/GfQXyGNQlrCx6VJhC/OyluqkEGhjtkTKg2EH++40DYti0LSgScr
pN8SPe5aRU3LoVB7BkO4gHBFBdNm2luST/eGEHPCfEat+LQ8CgUZdARtIyxr
G5s1NZ9CjKcmf5wIa14/eGTqBwptMaAT/semxUs1phaQ9+9V/L2VsOMUQaX8
Jwo5RyYfWkPYx/z9VfnPFLoyt9Z1PuEbZy+ayReT/O58kSdFODFv44DcVwoJ
fVacriXnLRBRSXKlFHoWfvVBPOGGlXXOcmUUevy9YNZhwoLjT5hy5cS/pmB8
LmFm6qHPsr8o9M1/tVkVyZcOX/e0bCWFqPjkhrOELRYP68pWkf7c5VqjQdj1
UH67TA2Fhv87oZdL9Dgdfylapo5CGg0S7ZaE77Za28o0kP4MXdD/g+j3ZjZb
UqaJQl2JEjtt/6enc322dDOF5Oxez/xE9P8bHech3UqhhbE2K5YRnsleVjWl
g0LRz/4c6iP1pb9FeG1KJ4XyvnEuriW8KRTDlG4KlXoWDISmEb1kbZ9L8Sl0
Yq/CdzlSn/wx90BJAYVa/gRuukfqfYfjxoWiYQqFMqeUPif98Cl9cRVfRKEP
/xK56ck0jnbn6taNU4i/T0npNemntTWebW+msFDq9LwRRPrx9QrbsAQZFmqK
XH6eQfp15q2lpg/lWKj00rXE6jga966j715WYKG5b34UW8fS+EG6t9VuDgsJ
XT03/yLzQHr6luFtSixUH5iUujuaxt7uy55tUGGhtXK5L1rvkfzO6R/XV2Mh
ht2ePT8jyfwIPZ46VZuF2oLnlm4g88fS3Vc5V5+F3ufoDMafpXF60failJUs
pHm0JSD5DI3V5xj6PDNiocw35TeTTpP5XT387ZYJC7VsuGl/9RSp33X+Zw+s
ZaF3hW2Of71oPKgR2MGyY6HAZFGEtDONXQKdI+S2s1DdA961izuIPtUmaNKB
hU4ociRHttM4JnQ8utuJhWqSbU9820Jjq7Egm497WUjKK2e97HoaP6kOzvA6
zkLRm83Uu3Rp3FGk9yf0JAu1pmlffahD6injj9zrU+T/FUWd6xaSfRNm6kKf
Jvn7/Pd8gCaNSzeI5LwvstBORvbUI2waC995uxy7w0Ln1ApzDwn42OzF7Gu3
77GQscBf8XQ/H1+IKstIjWahzdlDVhf4fKx4Uke+/xEL7fNS8DvZwcdzl3Zm
+CSwkPPq6zeaf/OxbayL/IlsEp/VEn55GtnHoYoGkbkslFux33VNCh/XBr53
yXjHQmpN314lkn26b4dq5iBmoU8iiWr7WD72p6pdThazUHaDg43RTT5+dtE2
07eWxKdXo8rZz8cjh0xd/UdZKEj3QeUCBbK/3y1CJ8dZCNNLVbNl+PiBgrLG
sUkW0mvR9TWR4GOTtP4/hyTZSIdFH9Ah94eg0UQXx6ls1P4mbM6TZh6WDKVc
DFXZSPvUbI/GVB6elv5v19AqNjrUpFL20IaHnaf8Nu0zYaPwkwVu09bz8CuH
AjWeGRtdXCIx7IN42HbsYWO7ORtt5oeraq/g4bB1W3dVWrHRyI/eNWrKPMyu
yXNO38lGXTduH3Zu5mK18dtOxwLYKHTlVH2mOxdbttrk3gtkI+fznxa+3cPF
J77IKeUHsZF6xiUfR3I/+3o7+Jf8BTbaN3eN6IQlF/vOO7bh2XXif3zNhyXz
uLh802bD6ods1CfjY//oTw8+H6fIMsVstPacurOnVQ9+dfmr996PbFSr9Tc3
H/XgGo+QsquFbDTRN2vDFMMevNRw4mrVFzaKqDEfPja3B9d/44l5l7PRTr3M
YyWj3Vh/qJQf18JGd5/tqzj6oht3rL/+VVaKg0x+Np+7PdmF3Ta6amhLc5Dp
drbV28Eu3Ghr4LtGloMqjrgE13R14Ur7P3MCpnGQ6pU6/aGKLlywd4V/D5uD
qvbqX32d2IUfna2fX6bNQTU/xFLm2XRhu+zFlyLWc5ClVsMddlgnLpxXCurX
Oagt8LgwfKgDW4X+sZpxk4OSpgeLD3Z24PKhfnvFWxx0j6EYsLGhAzd9UvGY
COegoDWlaY0FHVjodjCq6T4HyT43pW7d6sA6MRJ9j19wkPaw4cjc+R34rpJx
3OyvHPTIfY+d3Ka/2F02QWqO3AxkmfVsg21wG86O1TItvD0DCRLS5pXMaMJl
q02KtjKVkIdmVxXHthIL3R9scw1VQmjrnXmy+wpw8eYYe4UZyuhDqOCdhHE6
uBmbJCZGKiNH8+as3CmVcJj3fajhrjKKckwPFNtUCd5PXNZS0crIL0Og7R9V
CWflLrQEPlJGxaUtP8R0fsPD2hLVrQnKyPKe9AYv+yqo8ncIG8tWRsIjTV86
U2vA6q2P/5Z68jxWJyImvBG2eEkVhzQSfjfyO6C1ERw1787I+0PO07ew4uby
Jjh4LTd9XrsyUjba/sWpogku7hTjj3KV0b5b6ffKpjZD/shNt4QJZcT4Z//1
mH0LFKXMTq0XU0GB19tcF55tgVK31EmGpAqKGrzgN5HUAvVfKx+ellFB7JnH
osTHW0B4X7V6M0MFNZ+9FOuV0AqTtq+0QygVxDDdsJbzsxWkJeHEO7YKupLh
u75utBXYR9yY81RUkLVpYSPe0gaqswddnFRVUA2L9aI5sA00Ky6lhKkRf95L
LTWS2mDRZaXxotkqqLxR6ndQRRssW/184+gcFeQxluQ5NtEG/wdOwPMS
       "]]},
     Annotation[#, "Charting`Private`Tag$16587#15"]& ], 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwl13k4VN//AHB7ljBzZ4SESKkQFVHhfRLKkhayRIgSkkSRJUklS8kebaQs
1ScKIcmRUkhSRFIqSbaZazdj/d3v8/vrPK/n3pm597y3M0puJ/Yd4ePh4XnC
y8Pzv5Ufizb90TlvOFn1/+vK/qqtCskucP1Z+9gyap1+onm4I+kE+KeWGLdS
61+mJ6c06RxEPHgVkk2t30wv1uQkXQP581mN1tT6xSVJ9XZSJmwyEbfZn5gJ
+3xkv6UnFYI2nn4ZfLUQEkeditOSMGyWemAsH45ha625qFFAM1ysfGkiatIM
fiFWh4r9vkJZ0Gvtyo52OF5+JJ5vxS9Y+Ujh486hLmjtMxPJc+uBP70dDrXC
fyBWc5Kn1KEPlBY95DWn98JJtbrU6pwhmAx4p/OI0wc9R3oiskqHwDewfIUO
fz/YZvH4RLwbgkcR4vLl4v2wRWqzEeofgiZX7VUPlPuBb+EBG6uzwLB/yTZd
y35I+hy3AxezwOloNpP3Tj8UBe/mvnzFhm0d7ad19Qdg2v1YwQ/fYbi4pK/p
utsguNLHzlQGDkPSgqPic+9BqK0K2X4zfBi8Did/aPEfhATZ2K/28cNwxSJw
60TkIKh+zOdrfTwMAlaxq/qyB8FmS69tw9AwnHRfGXfl9yAU0A4tlHqPQGGq
zfEahyFgVvXVp/qPgN4rvnqxQ0MQfMwv5VTICHR2fjO18hwC47fn1myIHYGZ
z/zZVYFD0Bl6x/rxgxEQLvLPsUweAuF/nXn3+kZA0VjCddn7IXB7absnwWMU
Am3wZLgOCzaUyhCyJ0bhwMSK2AB9FvAVfmu5GzQK9kpajS7bWZCd5WxXHD0K
M5muNop7WdB9wcO57eEodGUlGm7xYYGbeaDPMnIUhHTDPvzIotyeGp0fNAa7
PLewmvjZsKHZznx9xBhE/W4veibCBr562cUV0WOQcahsKFmSDdkVt6+9zxiD
JvvE0k1ybOi+nZPGfjEG35/EnZLawAa3w8/ua/OMw3nsp7XJmQ3uI63V1dHj
kBjq9ZNbyAbXkAS78oRx6Hi0zD2khA1O/JbswvRxMNL6YDZWzgZbqddymfnj
wEkp39pExXHn5qeBZ+vG4QysSF7dwoZ156+qbxGegOrRT0q+42xYK2r2ej1t
ApKu+dic4rBBNVngwBqZCRh/vKbDf5YNy3NCL8usngBNbekv9gIkMOq9uid3
TEDhhbDQOgYJHJppevHlCei/eatAZz0J4xm8mo+uTcD6yuKEam0SRpRf1mZf
nwC/Ee6z7XokDGhrjyXmTUAHzni7AUj4Ya9s5fduAjyCDPqKLUmoyZrn11g0
Cc5tMqe2eZBQtabihorkJDx0blXZ40XCi6LT65dJTwJ6WCpm50NCyZshZzHV
SZBjDZ/Z5U9CXt+35/2mk2AmXFT5/SwJV7TKTuRGTYKLxAmLi8kkNGxo7z0d
Pwlaq7PVRNJIENaZOmiSNglV9TyXotJJuLhZ17InZxJqye4s79skhBqVrVau
nQQ7B8njX3NJKDduzxxpnITGZx5CSg9ImDSdWvKqdRKudzkx3R6R4G+hK+ja
MwmhB3ivfCgkwdum7Pdt/imwkEvqNCsnId+23f642BTcObJFzLaChF77qY/6
jClgfjz66EAlCYcO6lZ1Kk/BL+ejW3dVk2DvUXZD1mgKrs+PXWl/R8KOM2XW
qRFTcKiTLyXiC/W8Ie0Nh6OnoE15Sxqjndq/sKlt2gmULeX5Mr+SYHheV6sl
cwruavlJZXaSsCm2bDEdT8Hg12PLjX+TcOpK+4Vfb6dASFPW40Y3CUXxU9OF
TVNQjYqJ/j8kaCTr9lt1TcELD7/ME70kqNwqq70yNwUxbe/ClQZJcLvTru8k
yAGDoMtjW4ZIyMqaKlYT50BBXF+jJYuEZTm62Q3LOPCjI+4/B5KEA3l2sjdU
OCDIu7fIZpiE9AdBCV7qHHgf+FJu5wiVXwVl4cL6HMiWy5WRGSNhz5P2ifbt
HNhWUfxonHJ80ZRPngUHaqLi7taPkyBaputo6siBY2ebS5wmSdj53O6zlDsH
5m78+LR0ioSoF0Fmf705sOvD+J5PlPmqy3QvhnBgYFfqKVUuCQ/Fidy5SA7M
B//a00p5n6MPMyiOA0vl2rXPTJMwnf82cjiZAxd1LZYzZki4N7l8xOsWB+oc
6IwcypbGoS5/7nOgOIFHfN0slf+JXz44PeaA24lR8QLKxhqxD3dXccBHaK9K
8hwJQyE9MvVvOcAbenYzh3JKneFlo48c+Cmpvt9mngT9JRkTL9o5YMs2Csqj
/Nd9zF3nFwe2vHmYOUI5/umuzwV9HBh+bdW0YYGK50IeWj3CgeD7y/iPUe6y
5Cu8y+WA610BwxuUo244ycvxceFHCDe8mvK6vtK4FFEuvDo9XPuDcpsOfVqc
wYUYx9/EKOXwC8c8L8txYXfI2yNzlFU/1bbxqHCh5/6tqgXKzQrLTULUuVCy
wV2eS/mMT0jxmDYXuhbkIvspL69oVTpuwIW1x98PNVOuW6SZ0GvCBUHXMwcL
Kfvtj5l3seJCuJF660XKMvf++HTYcsGef2zPXsrVwwad+1y48FOqs4VJ2csw
3azxKBcI/wmnj9T7E1dGy0z8uBCQsn8ognJFh+UqfIYLa8LpkWsou6nmpeid
58K3km0K9dT+ip7m5S+K4cJTI95XLpSLahxPqiVxwbn0uDeLis8BWunP+ze4
MKect9SfMp8zzUrhHhcUlzd/YlHxffTIu/L6Iy4U1YsnuFK24b5ZSy+h7seX
9zdQ+TFrqpgRW8mFRFVPZTXKlt0tp89+4IKSP73lE4fKB811PZNfuGC3cWuZ
NOVbZ6P3+XVxQUv56j0bKh9ZMgaa7iQXmKNRqcUTVHx35/btpE/DUunjfwVH
qfje5rGrkZ0GwSOH6AJUfXQNHKjdqjwNE0tCdnCpetKMksxet3EaTl02bamj
6q258owjc/80sINk/Wf7qPiIttRfPTgNq9eypor+UfGx19Bb5DENLJvIWFeq
nv3GfjOnA6ch2vZEexZV7/S1Fk0/06ehxstGrvQH1Z8WZdLrsqbBRs9PE32n
9vvvqM2T/Gmo2xcSWvONhMN3b3RGlE9DxebmykKq/5TLDPQpfZ2Gc1/VSfVP
JFydNFAX/TUNHtV2H858pOLTmnhi9N80nB671lv5gQSxhM2TNVPTcKKx871G
AwnOi2L4D0vPwMdQbd+iGhI2/v1uaqk4A9E5kuurqX4o/ForVlt1BhpiEza8
raLiGf6VJqg7A62vAsYqqH4qOKmqkGs7AxfCXoTsKCLhv563en2pM7B2/JAU
K5OE8zVLw5pvz0Do4Yc856j+bpvli8tzZsDhu/ZGkZsk8DgtMY15NgOjEsF+
QtR8sG45Yr32ywxUbhM+eD+O6gevBHx9mLPgdOllvO9pqt9kGt0bTpoFUV3B
rdu2k3C5rvlH5M1ZcLx/fGUKNd/ejjjLSN2fhYG81TJdW0kwMQ69uvnZLMSk
dC61o+ajUX9xUGT7LASM5Bf/UKHqf+NKS+ayOVA8z1pnSM1brXeLJnRz5qC0
/0uRTSUbTgynajY8noMyHNQfW8aGAlkVb6fSOUDKgbvLi9ig4YN+RrybgwZT
ZiEnn5rv9OD6+v45MM7U6ZFMZYOK48Btx3XzcFZ5t1fGMTZIk42m58rmgSVc
H7aCYEN6Ij7Uj+chUlJT2nkxG2S0i8Ks6+bBv0rSLUGIcvD1ItWOeQgSLJT8
Ps2CpfxuCs3T87DJ6t+U5B8WKEhPTSw3XAC9q59PDD5lwSpQyql5swCDm97T
z5qx4Ma7Cl5+Lx40oJK8MsB1CIZ/PQkmfXiQbZRV/jrq/LdjOnek048HCWyz
cPizdwjG1ZN/l5zhQXmrJHfpbR8Cq6RjrzyiedATRbPHCSuHgO/gsvMNeTyo
pnNF92zfIBwbPcuT1MuDtvNFLnykzqf68tsWlh/mRZe8K+w/HBiAnU6t/m6e
vGjUffSv0t4BsLl5tPeeDy+6Tn/Kc2LHAByTjf+w6jQv+sLA/aMbB+CGVOdN
9ShedHt1aPvdxQPAET+tp5fPi1bS9ZPvVPZDyXz+yd1DvAh1saNUpftB7Ret
5+wpPvTmVlW3fNk/eJxPeD7z50d04mG9388eCOs62KIWJYDkxASWXfD9DSf1
9SzupAiiB3XX928M74TpTGO3wQQhlPHmrlzdulZo9rvhGpS9CDlfrOs60foO
Nu9Qnv9xVxgpHLqkMcHzBOpNNuejWyIo+Nahhs9XCnDO04zN3Y9EkcdVcW5p
UB2WWqHu7fxADAmzfqfa/m3Bn3mFI2UrF6PcmDUz1t868TPhgNzmenEkGlcS
+SvtN1aXonm71Uqg+sALm+Nf9GAyfpK5sU0SeYk2ZJyr/4eHhhVqNL5JIqXl
ZRorWv/hgX07TqzukkSj9dwf1V3/cM+S9Hr5Xkn0N0IsZmDsH/52Z3O48KQk
KqBdqp6U78NudlVjbFEaUr7c4T/s14d3HeU9+GYtDeW6e6vYEf14xeXLmie8
aUghLq/G02gA+7dph7v50NCLlTqL9lkM4OqV3Y37fWmoaKZIXMdmADu/0ffW
96eh86sU7PuODOAbvKP3RUJoqH/GOZ8/ZgATYU5L78fQkO09lqdY0wDmO7le
sCOfhgKLR3bttR7Ee6u7rBsf0tD24/u7fB0HcZbklWz8Hw051V0ZvuQ+iA0L
eiH3CQ39ku5MygoYxCGDN0MCymno+m3JG5eTB/HoEaFh8ToaKvfpoMl9HsTd
Bzq/Gf2jIa3YwT/m5kN4sYFdnms/DaXLn87cuG8I6yi2BIQP0hDbMuck88AQ
jv7TsLiCpO5nm+2t8hrCmj4Vhus5NCRaafuqKHoIh53NyFYUoSP5M4kxy2qH
sFSWnffsWjq6xiEd/+qysGFky6alGnQUqZHS3WjIwp6Hd/PradIRc/aN4X8m
LFy5esetgI10ql5M/PZZs7Db001NA1vpyLAo4YK+LwsX1Eht6LCko6bb2Z8u
ZbPwzr8t3Ge+dDRbuubFLwE2PqsWH1roR0eEVz7TUZSNi07unMv3pyMJ7pxS
kyQby81X8twKpCMvO2HrO0vZmL0kd1FkOB1FdM0M9GqyccrOM1JW8XRULhze
Ke3Axr8eLVvf+5iOxHujvIZz2FhqtK3oZyEdXZX71B3+kI3N9RK1O57SEctq
34BgIRsXvxHUa3xGXd/1OnOujI2jfrANi17SUdqo5eXkeuqvrOQry/APdIRu
ZnvYD7LxGf8jnktYdJTyLKIM1pA42oJ9dAtJR96dbWlqGiS+rhJ01HmEjo7l
KiRLrCdxaVu0R+4EHamWOnc91yPx2Jb/Dm+ap6OdBrr3cnaQ2Jd/zNVWkkAq
vXVin9xJfPZ7qGsInUAHRM9tX3eUxFeeCbjeYRCoaep9dKQ3iR8dXeLSK02g
+ftP9WgnSdz3fvPBwOUE+jAwJVV9lsTuKREOaesJ5P7iCf1kKon9j4s4VGwk
kM4Rq2rDdBJHmibZd+kQ6CK98wT/TRJnce7ZrdpCoDOPJptOZpG4y+nd/lIj
Ao0HGYd0PyQxS2fP/m/GBCILbOQ9H5N4VqLDZt6UQHK+gpU9hSSWezVgbWpB
IGT+pb+mhMT2KyX2tVkT6G/i3UmiisSe82l7p/cTaNeYlMeeahIHtSvuVbAn
0LumuMaLNSROi1m/x8OJQLyFrmGf35K4hWVjNXmYQB1psQ68H0lsVXrTfEkg
gaq139/97wf1fWNuC1JnCGQcbK5u8JPEF7TWlkiFEMhI7t3H2l8kLn9YLi8V
Tr1/fIIr/kNi5cwvw4woAr3We33Xup/E+t9v5TCiCTSRf3bo/gCJ7WQPH2DE
EghyllmxB6n9Th59TcQTSHOpyn4vNoknL0tep6cRiOdJkg/PGIlptW0W9HQC
FXjd8iTGSazGd4eHfoNA8Snc4GUTJHYNU/em3SHQYlmJ7zJTJA55PqZAyyLQ
waIQdTEOiVMnK1oks6nf189JnKDc4GdmIJlLILpcaUbRNIl7HtNGJfIJdOyl
m/6lGRIvDLTnSjwkkNOww9juWRJrH/GgSRQQyFml8faHOWp/sjVqxZ8Q6F6c
QiJ1XsVeP8eDxYsIlL7HO11tgcR3HC78WVxKoDCVAyPaPMO4PM08fXE5gX5E
fEgKp9zSQt+1uIJAbvRVhm8os2kdvIsrCRSY4zomyDuMha2ySsWqCJSnEFq0
nbJy3NFjYtUEmvU7FXqWskHduuViNQR6f8/SqpiyveBkq+gbar+bBdT+UvY3
ehkj+pZALJVMOoNvGF85d9FQtI5A1r8U+Awo51VajIk0EMjSNnrWjXINl8gX
aSSQKusXzyXK3zd9cxJpItA2RU3Je5QnA+7SRZoJpBgSovqSMv2p51vhzwTS
y3xv1kJZna0ZKtxK7dd29cC/lE3VpjSF2wjUqpn33xhlV8+qnkVfCZSxbSdr
jnJozqWMRd8IxPZapifAP4zTui2tFn0nkHTB+qtClJ8oMvkXdRFIcvX1of9d
b3DqLBP6RSBxoYO2C9Tn/2Zk+wh1E2g4NqVhgjJPu5eSUA+B1kjsMeujvJS5
vk2wl8qn2ezPbZS193JiBfsItKLtrscryrvjMQgOEMhmg5tgPmXv91HjAkME
0qicLoilfFHY6oEAm8pP7QvuXpTvmEg5CwwTKMSPucKY8vPI74TAKIFsnepY
Sym34nvv+McJ9Ibz/DWL2n/2rHcY/ySBtjgJ5lRSdrC3WMOdIlCwQ2dONOU3
xWptbC6BzmUmd+yhnOE9pPltjkBfJJS/faHyQeBt4/ePC1S8DDflJVH2VXoc
U8vLQH2v8/MsKBt/Pf7niSADabW6RB2m8q1wo1VC7iIGoulIvcRUPi69ts7g
lggDmUVmOjIoD5uQaZfFGcgdHfp0j8rnm8V+5s5SDFRUZJXvxSWxkOTeKWtp
BtrxZt+qaKo+/LzX3zeTZSD77kqJTKqeTJVG57TlGWixyoblpVS9jcYHPBVb
yUDtLNk9MSMkPjhg7cyrykDmgc/Vjg2TuM5EW2xqNQNd3/3plAlJ4tuz44e7
1RmIHim7988QiXd6B8o812agu/Lmhm/+kbi41ra2YBMDNRp+T/TqJbGCkq7/
fT0GcgwIsV30l+rf7VPvr+kzkHrYe231bqq+TILPeRgzkM2lN9Zy30ksctdB
3cmUgXZFPTa4+I3Ep2Y3d+zdyUBNG8pv/f1KYrPi6Q0GlgxkOO1emfiFxOPL
w3oZNgykqvQ78VoTiV3CnJJFbBno9qpU7cpGqj+066MFOwZyusm393cDiTPj
5zIGHBko3jeMy3xHYvPZ8F2v3BnIYW3EUmVM4rvt50t8AxjIiK6o1Ur1695a
rZ/xpxnIL8422/YRidVLfooUBjHQkZQvps351HxKMHAhQ6n3ifNf++AeiRvN
uCJ+F6nnu4KCRqh5wXnh53IylYEij2wX+XGexIYPFWMTrzNQVI+FdEs41X/T
m0qeZjDQzmAhz+pQEkucVhcdvU3FfwWtLeI0iVes6yvxz2UgFn+MQIYn1a+y
XERPlTHQqRKxZ6q7SJwSL6GT8pyBTq8dCEkyI3FH2EuXkhdUPPhw2rgJiQ87
yD0bxwxUIXr+yx1DEgcT7S6n6xjIYn9oSpwmie9ftHoW2MFAVY8czN9Jknja
08A1eIaBdj9Ve/mJmt/mL9ai03MMxMtOrAyuZeOb4jLLTy4wULXyH/ulr9hY
v2j0pyc/EznX/3fcpJyNw2fyXOzFmEhzh8q67blszB9PuOjKMdFUE8O4K4KN
Fxf/OzixhYnOBQjw39ZiYyfBLwYj+kyk/a/Xw1GNjR/b1cizDJlIeqnsdWIV
G1vN3vrRY8REfaYst2NybJxgsu9gqzkTJZ20aXsryMbMr5VOxQeYaKLI7d6q
DhaWn0t0PBnCRGvdzATTQqjzUveu59fDmOhIR7gTK4CFT70Tka4KZ6LSsI4I
/eMs3JB4/rPoBSY6XPJkS40LCweuOml2P46JjApOlR0zZuHm3Xt0228xkYl9
D//mxSwcmS3BMMBMFJcYudCUOoR7d8Q1CAtIoZMSiX4XEgexm4Xr8pVCUmj5
TykfsZhB/MNKJ3CbsBQq+BSkcSViELfu/6kUslgKiZeOi585MYhr3DcGDzKl
kEyp202u5SC+fa5TtWmlFBLrhTu5QoPYpkztUvIOKfRwMTuh6tQAfr2qERTi
pFCIRq1Dtn4/9hbOFVASWYL8fNjEleJeXJalYvA6cQladt6Fxp/5Bzdt1a/d
R5dG2adNH76O+IU53jetXeOl0ZnwGDH7tG+4bk/mfvElMmiNZVUST0gLdtus
n5eXIoN85nKzLrTWYy/Wh4nvaTLoCq9E5+iNeux318WYyJBBzG9+gb6H6vE5
kQu/w27LIM5T7wtx7Dp8q6Nebl+uDEI+uX8OidThtmC7hNkyGfT1+OX4vG1v
sXmFf/DeThnUGKaR0vmyBu/1FaiL+iGDUubKaVpRNdheOW1J5U8ZtCzzwps0
qxp8NPZ58aoeGSSDN6be/PkKXzzAw54ZkkHp/KJbovle4arpq2658zKo70/H
5Pr0KlxboPi0k0cWaT28r7VHrQo3uj1doPHLonSrnYyMqpe4s6H1VugiWfQ1
zvHYf38rMeeGXPsemiziCO3P6tF5gResHq+MImSRvVaKvXtDBRbih1MvmLKo
vDppRNKlAjOPUZNeVhbxnNI5Oh79HMspjrs4ysmiaMsdUhoKz7Fyy6WCBHlZ
1Jw6bppaXI7XXpaeq1WURTIBhUc0zMrx+q0PLGaUKMfqdE50leH/A1znnVs=

       "]]},
     Annotation[#, "Charting`Private`Tag$16587#16"]& ], 
    TagBox[
     {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwl13k4VN//AHB7ljBzZ4SESKkQFVHhfRLKkhayRIgSkkSRJUklS8kebaQs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       "]]},
     Annotation[#, "Charting`Private`Tag$16587#17"]& ], 
    TagBox[
     {RGBColor[0.560181, 0.691569, 0.194885], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwl13k8VN3/AHBrtmTmzgiVrX0RCVHhc56KsqQsRSWEJKlQyJJKJY/KYw8p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       "]]},
     Annotation[#, "Charting`Private`Tag$16587#18"]& ], 
    TagBox[
     {RGBColor[0.922526, 0.385626, 0.209179], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwl13k8VN3/AHBrtmTmzgiVrX0RCVHhc56KsqQsRSWEJKlQyJJKJY/KYw8p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       "]]},
     Annotation[#, "Charting`Private`Tag$16587#19"]& ], 
    TagBox[
     {RGBColor[0.528488, 0.470624, 0.701351], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwll3k0ld/bxg3JWJznGIukSYNoMKTo3gkRaSASxVeSJEmlSJImlWRKkjKU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       "]]},
     Annotation[#, "Charting`Private`Tag$16587#20"]& ], 
    TagBox[
     {RGBColor[0.772079, 0.431554, 0.102387], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwll3k0ld/bxg3JWJznGIukSYNoMKTo3gkRaSASxVeSJEmlSJImlWRKkjKU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       "]]},
     Annotation[#, "Charting`Private`Tag$16587#21"]& ]}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->
   NCache[{{0, 2 Pi}, {-3.7419861114051036`, 3.8253667893922274`}}, {{
     0, 6.283185307179586}, {-3.7419861114051036`, 3.8253667893922274`}}],
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.723540245119697*^9}]
}, Open  ]],

Cell["5. Generisati fibonacijev niz pomocu generatorne funkcije. ", "Text",
 CellChangeTimes->{{3.7235402589257216`*^9, 3.723540277505354*^9}, 
   3.723540340701065*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CoefficientList", "[", 
  RowBox[{
   RowBox[{"Series", "[", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"1", "-", "t", "-", 
       RowBox[{"t", "^", "2"}]}]], ",", " ", 
     RowBox[{"{", 
      RowBox[{"t", ",", " ", "0", ",", " ", "15"}], "}"}]}], "]"}], ",", " ", 
   "t"}], "]"}]], "Input",
 CellChangeTimes->{{3.7235402802509584`*^9, 3.723540319578628*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1", ",", "1", ",", "2", ",", "3", ",", "5", ",", "8", ",", "13", ",", "21",
    ",", "34", ",", "55", ",", "89", ",", "144", ",", "233", ",", "377", ",", 
   "610", ",", "987"}], "}"}]], "Output",
 CellChangeTimes->{3.7235403206082296`*^9}]
}, Open  ]],

Cell["\<\
6. Generisati Lezandrove polinome pomocu generatornih funkcija\
\>", "Text",
 CellChangeTimes->{{3.7235403330414515`*^9, 3.723540350373082*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CoefficientList", "[", 
  RowBox[{
   RowBox[{"Series", "[", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"1", "-", 
        RowBox[{"2", "*", "t", "*", "x"}], "+", 
        RowBox[{"t", "*", "2"}]}], "]"}]], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", " ", "0", ",", " ", "5"}], "}"}]}], "]"}], ",", " ", 
   "t"}], "]"}]], "Input",
 CellChangeTimes->{{3.723540353742688*^9, 3.723540413599993*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", 
   RowBox[{
    RowBox[{"-", "1"}], "+", "x"}], ",", 
   RowBox[{
    FractionBox["3", "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "x"}], ")"}], "2"]}], ",", 
   RowBox[{
    FractionBox["5", "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "x"}], ")"}], "3"]}], ",", 
   RowBox[{
    FractionBox["35", "8"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "x"}], ")"}], "4"]}], ",", 
   RowBox[{
    FractionBox["63", "8"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "x"}], ")"}], "5"]}]}], "}"}]], "Output",
 CellChangeTimes->{3.7235404159243975`*^9}]
}, Open  ]],

Cell["Lezandrovi polinomi generisani ugradjenom funkcijom:", "Text",
 CellChangeTimes->{{3.7235404224920087`*^9, 3.723540429558821*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"LegendreP", "[", 
    RowBox[{"n", ",", "x"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"n", ",", "0", ",", "5"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.723540433427628*^9, 3.723540448341254*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "x", ",", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["x", "2"]}]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "3"}], " ", "x"}], "+", 
      RowBox[{"5", " ", 
       SuperscriptBox["x", "3"]}]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "8"], " ", 
    RowBox[{"(", 
     RowBox[{"3", "-", 
      RowBox[{"30", " ", 
       SuperscriptBox["x", "2"]}], "+", 
      RowBox[{"35", " ", 
       SuperscriptBox["x", "4"]}]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "8"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"15", " ", "x"}], "-", 
      RowBox[{"70", " ", 
       SuperscriptBox["x", "3"]}], "+", 
      RowBox[{"63", " ", 
       SuperscriptBox["x", "5"]}]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.7235404494488564`*^9}]
}, Open  ]],

Cell["\<\
Vektori u Mathematici
Definisu se kao najobicnije liste, na sledeci nacin:\
\>", "Text",
 CellChangeTimes->{{3.7235405030349503`*^9, 3.7235405230341854`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"vu", " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{"1", ",", "2", ",", "3"}], "}"}]}]], "Input",
 CellChangeTimes->{{3.7235405247189884`*^9, 3.723540534781006*^9}, {
  3.723540621251958*^9, 3.7235406226091604`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "2", ",", "3"}], "}"}]], "Output",
 CellChangeTimes->{3.723540537557811*^9, 3.723540624730764*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"vv", " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{"7", ",", " ", 
    RowBox[{"-", "5"}], ",", " ", "3"}], "}"}]}]], "Input",
 CellChangeTimes->{{3.723540539242614*^9, 3.7235405469022274`*^9}, {
  3.723540628755571*^9, 3.7235406297695727`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"7", ",", 
   RowBox[{"-", "5"}], ",", "3"}], "}"}]], "Output",
 CellChangeTimes->{3.7235405483842297`*^9, 3.723540630518374*^9}]
}, Open  ]],

Cell["Kao i u matematici, sve operacije sa vektorima su podrzane", "Text",
 CellChangeTimes->{{3.7235405547490416`*^9, 3.723540572704673*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"vu", "+", "vv"}]], "Input",
 CellChangeTimes->{{3.7235405755282774`*^9, 3.723540635525983*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"8", ",", 
   RowBox[{"-", "3"}], ",", "6"}], "}"}]], "Output",
 CellChangeTimes->{{3.723540578882283*^9, 3.723540636274784*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"vu", " ", "-", " ", "vv"}]], "Input",
 CellChangeTimes->{{3.7235406392855897`*^9, 3.723540640658392*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "6"}], ",", "7", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.7235406410795927`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"5", "*", "vu"}], " ", "+", " ", 
  RowBox[{"3", "*", "vv"}]}]], "Input",
 CellChangeTimes->{{3.7235406437003975`*^9, 3.7235406550416174`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"26", ",", 
   RowBox[{"-", "5"}], ",", "24"}], "}"}]], "Output",
 CellChangeTimes->{3.7235406556968184`*^9}]
}, Open  ]],

Cell["\<\
kad je proizvod vektora u pitanju, definisane su tri operacije:
1. Pokoordinatno mnozenje: operator *
2. Skalarni proizvod: oeprator . ili funkcija Dot
3. Vektorski proizvod: Funkcija Cross
Za operaciju Cross, vektori moraju da budu trodimenzioni\
\>", "Text",
 CellChangeTimes->{{3.7235406641832333`*^9, 3.7235407600454016`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"vv", "*", "vu"}]], "Input",
 CellChangeTimes->{{3.7235407629002066`*^9, 3.7235407642262087`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"7", ",", 
   RowBox[{"-", "10"}], ",", "9"}], "}"}]], "Output",
 CellChangeTimes->{3.723540765224611*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"vv", ".", "vu"}]], "Input",
 CellChangeTimes->{{3.7235407667690134`*^9, 3.7235407679546156`*^9}}],

Cell[BoxData["6"], "Output",
 CellChangeTimes->{3.7235407697018185`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Cross", "[", 
  RowBox[{"vu", ",", "vv"}], "]"}]], "Input",
 CellChangeTimes->{{3.723540771527022*^9, 3.723540774959028*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"21", ",", "18", ",", 
   RowBox[{"-", "19"}]}], "}"}]], "Output",
 CellChangeTimes->{3.7235407759106293`*^9}]
}, Open  ]],

Cell["\<\
Ugao izmedju vektora moze da se pronadje klasicno, pomocu skalarnog prozivoda \
ili koriscenjem ugradjene funkcije VectorAngle. Funkcijom Norm se dobija \
Norma vektora.\
\>", "Text",
 CellChangeTimes->{{3.723540792212658*^9, 3.72354084448835*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ugao", " ", "=", " ", 
  RowBox[{"ArcCos", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"vu", ".", "vv"}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Norm", "[", "vu", "]"}], "*", 
      RowBox[{"Norm", "[", "vv", "]"}]}], ")"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7235408197311063`*^9, 3.723540820698308*^9}, {
  3.7235408567343717`*^9, 3.723540902161651*^9}}],

Cell[BoxData[
 RowBox[{"ArcCos", "[", 
  RowBox[{"3", " ", 
   SqrtBox[
    FractionBox["2", "581"]]}], "]"}]], "Output",
 CellChangeTimes->{3.7235409028012524`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"VectorAngle", "[", 
  RowBox[{"vu", ",", " ", "vv"}], "]"}]], "Input",
 CellChangeTimes->{{3.7235409096496644`*^9, 3.723540915374874*^9}}],

Cell[BoxData[
 RowBox[{"ArcCos", "[", 
  RowBox[{"3", " ", 
   SqrtBox[
    FractionBox["2", "581"]]}], "]"}]], "Output",
 CellChangeTimes->{3.723540916201676*^9}]
}, Open  ]],

Cell["Ili Numericki u radijanima", "Text",
 CellChangeTimes->{{3.723540925046891*^9, 3.7235409346253085`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.723540937792114*^9, 3.723540939445717*^9}}],

Cell[BoxData["1.3938601703935367`"], "Output",
 CellChangeTimes->{3.723540940631319*^9}]
}, Open  ]],

Cell["ili u stepenima", "Text",
 CellChangeTimes->{{3.7235409462473288`*^9, 3.7235409483533325`*^9}, {
  3.7235410633567343`*^9, 3.7235410639651356`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"1.3938601703935367", " ", "/", " ", "Degree"}]], "Input",
 CellChangeTimes->{{3.723540950443736*^9, 3.723540955045744*^9}, {
  3.723541052826716*^9, 3.723541057974725*^9}}],

Cell[BoxData["79.86230499493544`"], "Output",
 CellChangeTimes->{3.7235409557789454`*^9, 3.7235410583803253`*^9}]
}, Open  ]],

Cell["Povrsina cetvorougla definisanog sa ova dva vektora je", "Text",
 CellChangeTimes->{{3.723541086631975*^9, 3.7235410976455946`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"povrsina", " ", "=", " ", 
  RowBox[{
   RowBox[{"Norm", "[", 
    RowBox[{"Cross", "[", 
     RowBox[{"vu", ",", "vv"}], "]"}], "]"}], "*", 
   RowBox[{"Sin", "[", 
    RowBox[{"VectorAngle", "[", 
     RowBox[{"vu", ",", "vv"}], "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.723541100047999*^9, 3.7235411261000443`*^9}}],

Cell[BoxData[
 RowBox[{"563", " ", 
  SqrtBox[
   FractionBox["2", "581"]]}]], "Output",
 CellChangeTimes->{3.723541127051646*^9}]
}, Open  ]],

Cell["\<\
Da bismo dobili zapreminu prizme koja je definisana sa ova tri ugla, potrebno \
je da definisemo treci vektor\
\>", "Text",
 CellChangeTimes->{{3.723541135366461*^9, 3.7235411602329044`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"vw", " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"-", "3"}], ",", 
    RowBox[{"-", "2"}], ",", " ", "7"}], "}"}]}]], "Input",
 CellChangeTimes->{{3.7235411621205077`*^9, 3.7235411719485254`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "3"}], ",", 
   RowBox[{"-", "2"}], ",", "7"}], "}"}]], "Output",
 CellChangeTimes->{3.7235411732745275`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"zapremina", " ", "=", " ", 
  RowBox[{"Abs", "[", 
   RowBox[{
    RowBox[{"Cross", "[", 
     RowBox[{"vu", ",", "vv"}], "]"}], ".", "vw"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.723541177127734*^9, 3.723541195270566*^9}}],

Cell[BoxData["232"], "Output",
 CellChangeTimes->{{3.723541187579753*^9, 3.7235411956917667`*^9}}]
}, Open  ]],

Cell["Projekcija vektora se dobija pomocu funkcije Projection", "Text",
 CellChangeTimes->{{3.723541265501889*^9, 3.723541308027564*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pvu", " ", "=", " ", 
  RowBox[{"Projection", "[", 
   RowBox[{"vu", ",", "vv"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7235413098371673`*^9, 3.723541318229982*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox["42", "83"], ",", 
   RowBox[{"-", 
    FractionBox["30", "83"]}], ",", 
   FractionBox["18", "83"]}], "}"}]], "Output",
 CellChangeTimes->{3.723541322223589*^9}]
}, Open  ]],

Cell["\<\
Provera da li je projekcija ispravna -> skalarni proizvod mora da bude 0\
\>", "Text",
 CellChangeTimes->{{3.723541329259201*^9, 3.7235413581972523`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"vu", " ", "-", " ", "pvu"}], ")"}], ".", "vv"}]], "Input",
 CellChangeTimes->{{3.723541360381256*^9, 3.723541374514881*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.7235413697880726`*^9, 3.7235413749984818`*^9}}]
}, Open  ]],

Cell["\<\
Vektori podrzavaju i indeksni pristup, pri cemu se indeksiranje radi pomocu \
operatora [[]], pri cemu indeksiranje krece od 1\
\>", "Text",
 CellChangeTimes->{{3.723541410457344*^9, 3.723541465541041*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"vu", "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.7235414305501795`*^9, 3.7235414464934072`*^9}}],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{{3.7235414347309866`*^9, 3.723541446992608*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["vu"], "Input",
 CellChangeTimes->{{3.723541456383825*^9, 3.723541456461825*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "2", ",", "3"}], "}"}]], "Output",
 CellChangeTimes->{3.7235414572106256`*^9}]
}, Open  ]],

Cell["\<\
Pored pristupa, na ovaj nacin mogu da se menjaju i vrednosti elemenata\
\>", "Text",
 CellChangeTimes->{{3.7235414799866657`*^9, 3.723541491780287*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"vu", "[", 
   RowBox[{"[", "1", "]"}], "]"}], " ", "=", " ", "10"}]], "Input",
 CellChangeTimes->{{3.72354149343389*^9, 3.7235414963822947`*^9}}],

Cell[BoxData["10"], "Output",
 CellChangeTimes->{3.723541497037496*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["vu"], "Input",
 CellChangeTimes->{{3.7235414986442986`*^9, 3.7235414987378993`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"10", ",", "2", ",", "3"}], "}"}]], "Output",
 CellChangeTimes->{3.7235414990810995`*^9}]
}, Open  ]],

Cell["\<\
Matrice se u Mathematici predstavljaju kao vektori vektora, tj. na sledeci \
nacin\
\>", "Text",
 CellChangeTimes->{{3.7235415261939473`*^9, 3.723541540202772*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"A", " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "2", ",", "3"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"4", ",", "5", ",", "6"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"7", ",", "8", ",", "9"}], "}"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.7235415428235765`*^9, 3.723541554320797*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "5", ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"7", ",", "8", ",", "9"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.7235415553815985`*^9}]
}, Open  ]],

Cell["\<\
Da bismo pristupili elementu matrice ili ga izmenili, koristi se indeksni \
pristup\
\>", "Text",
 CellChangeTimes->{{3.7235415635716133`*^9, 3.723541574850433*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"A", "[", 
   RowBox[{"[", "1", "]"}], "]"}], "[", 
  RowBox[{"[", "2", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.7235415769720364`*^9, 3.7235415832120476`*^9}}],

Cell[BoxData["2"], "Output",
 CellChangeTimes->{3.72354158474085*^9}]
}, Open  ]],

Cell["Ili krace:", "Text",
 CellChangeTimes->{{3.723541594178867*^9, 3.7235415960040703`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"A", "[", 
  RowBox[{"[", 
   RowBox[{"1", ",", "2"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.723541596784071*^9, 3.723541600044477*^9}}],

Cell[BoxData["2"], "Output",
 CellChangeTimes->{3.723541600528078*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"A", "[", 
   RowBox[{"[", 
    RowBox[{"1", ",", "2"}], "]"}], "]"}], " ", "=", " ", "20"}]], "Input",
 CellChangeTimes->{{3.723541604022484*^9, 3.7235416078756905`*^9}}],

Cell[BoxData["20"], "Output",
 CellChangeTimes->{3.7235416084840918`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["A"], "Input",
 CellChangeTimes->{3.7235416098412943`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "20", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "5", ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"7", ",", "8", ",", "9"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.7235416104652953`*^9}]
}, Open  ]],

Cell["\<\
Sve operacije koje se izvode nad matricama moraju da se izvode dok je matrica \
u ovom obliku. Da bismo lakse vizuelizovali sadrzaj matrice moguce je da \
prebacimo matricu u matricnu reprezentaciju pomocu naredbe MatrixForm. 
BITNO: MatrixForm je samo nacin predstavljanja i kao takav ne podrzava \
matricne operacije. Za bilo kako izracunavanje mora da se koristi vektorski \
oblik\
\>", "Text",
 CellChangeTimes->{{3.7235416196849117`*^9, 3.723541693363841*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"A", "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.723541694611843*^9, 3.723541700009453*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", "20", "3"},
     {"4", "5", "6"},
     {"7", "8", "9"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.7235417003526535`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"B", " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"10", ",", "11", ",", "12"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"13", ",", "14", ",", "15"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"16", ",", "17", ",", "18"}], "}"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.7235417043930607`*^9, 3.7235417202894883`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"10", ",", "11", ",", "12"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"13", ",", "14", ",", "15"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"16", ",", "17", ",", "18"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.72354172125669*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"A", " ", "+", "B"}]], "Input",
 CellChangeTimes->{{3.723541723159893*^9, 3.723541728604303*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"11", ",", "31", ",", "15"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"17", ",", "19", ",", "21"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"23", ",", "25", ",", "27"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.7235417298679047`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.723541735546315*^9, 3.7235417392435217`*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"11", "31", "15"},
     {"17", "19", "21"},
     {"23", "25", "27"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.7235417409439244`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"A", "-", "B"}]], "Input",
 CellChangeTimes->{{3.7235417430187283`*^9, 3.723541743580329*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "9"}], ",", "9", ",", 
     RowBox[{"-", "9"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "9"}], ",", 
     RowBox[{"-", "9"}], ",", 
     RowBox[{"-", "9"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "9"}], ",", 
     RowBox[{"-", "9"}], ",", 
     RowBox[{"-", "9"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.7235417443135304`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"A", "*", "B"}]], "Input",
 CellChangeTimes->{{3.723541747542736*^9, 3.723541747917137*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"10", ",", "220", ",", "36"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"52", ",", "70", ",", "90"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"112", ",", "136", ",", "162"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.723541748790738*^9}]
}, Open  ]],

Cell["\<\
Iako deluje intuitivno, A*B nije proizvod matrica, vec pookoordinatni \
proizvod, tj. ekvivalntan je matlab pozivu A.*B
Da bismo dobili proizvod matrica potrebno je da koristimo operator .\
\>", "Text",
 CellChangeTimes->{{3.723541771769579*^9, 3.7235418126260505`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"A", ".", "B"}]], "Input",
 CellChangeTimes->{{3.723541815122055*^9, 3.7235418160580564`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"318", ",", "342", ",", "366"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"201", ",", "216", ",", "231"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"318", ",", "342", ",", "366"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.7235418168536577`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"B", ".", "A"}]], "Input",
 CellChangeTimes->{{3.723541820504064*^9, 3.723541821549266*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"138", ",", "351", ",", "204"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"174", ",", "450", ",", "258"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"210", ",", "549", ",", "312"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.7235418222044673`*^9}]
}, Open  ]],

Cell["\<\
Matematika podrzava i operator za stepenovanje matrica. A^5 = A*A*A*A*A
BITNO: Elementi matrice se stepenuju clan po clan, tj. mnozenje se vrsi \
pokoordinatno\
\>", "Text",
 CellChangeTimes->{{3.723541831876484*^9, 3.7235419061326146`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"A", "^", "5"}]], "Input",
 CellChangeTimes->{{3.7235418405500994`*^9, 3.723541842125702*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "3200000", ",", "243"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1024", ",", "3125", ",", "7776"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"16807", ",", "32768", ",", "59049"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.7235418427029033`*^9}]
}, Open  ]],

Cell["A^(-1), nije inverzna matrica vec reciprocna.", "Text",
 CellChangeTimes->{{3.7235419133242273`*^9, 3.723541933869463*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"A", "^", 
  RowBox[{"(", 
   RowBox[{"-", "1"}], ")"}]}]], "Input",
 CellChangeTimes->{{3.7235419351174655`*^9, 3.7235419388770723`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", 
     FractionBox["1", "20"], ",", 
     FractionBox["1", "3"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "4"], ",", 
     FractionBox["1", "5"], ",", 
     FractionBox["1", "6"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "7"], ",", 
     FractionBox["1", "8"], ",", 
     FractionBox["1", "9"]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.723541939407473*^9}]
}, Open  ]],

Cell["Da bismo dobili inverznu matricu koristi se funkcija Inverse", "Text",
 CellChangeTimes->{{3.723541957363105*^9, 3.7235419663487206`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IA", " ", "=", " ", 
  RowBox[{"Inverse", "[", "A", "]"}]}]], "Input",
 CellChangeTimes->{{3.723541967799523*^9, 3.7235419715903296`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "36"]}], ",", 
     RowBox[{"-", 
      FractionBox["13", "9"]}], ",", 
     FractionBox["35", "36"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "18"], ",", 
     RowBox[{"-", 
      FractionBox["1", "9"]}], ",", 
     FractionBox["1", "18"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "36"]}], ",", 
     FractionBox["11", "9"], ",", 
     RowBox[{"-", 
      FractionBox["25", "36"]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.7235419722143307`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"A", ".", "IA"}]], "Input",
 CellChangeTimes->{{3.723541973493533*^9, 3.7235419755059366`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.7235419773623395`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"IA", ".", "A"}], " ", "//", " ", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.723541980014344*^9, 3.723541986129555*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", "0", "0"},
     {"0", "1", "0"},
     {"0", "0", "1"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.723541986675556*^9}]
}, Open  ]],

Cell["\<\
Transponovana matrica: Transpose
Determinanta: Det
Trag: Tr
Rang: MatrixRank
Eliminacija vrsta: RowReduce
Jedinicna matrica: IdentityMatrix
Dijagonalna matrica: DiagonalMatrix
Matrica Slucajnih brojeva: RandomInteger\
\>", "Text",
 CellChangeTimes->{{3.7235420236164207`*^9, 3.7235421400082254`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IdentityMatrix", "[", "3", "]"}]], "Input",
 CellChangeTimes->{{3.7235421166861844`*^9, 3.7235421242521973`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.7235421247669983`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DiagonalMatrix", "[", 
  RowBox[{"{", 
   RowBox[{"1", ",", "2", ",", "3"}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.723542145483835*^9, 3.7235421495866423`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "2", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "3"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.7235421504914436`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RandomInteger", "[", 
  RowBox[{"10", ",", " ", 
   RowBox[{"{", 
    RowBox[{"3", ",", "2"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.723542154906252*^9, 3.7235421770738907`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"10", ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"10", ",", "3"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.723542178836694*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Transpose", "[", "A", "]"}]], "Input",
 CellChangeTimes->{{3.7235421932355185`*^9, 3.723542195996724*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "4", ",", "7"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"20", ",", "5", ",", "8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "6", ",", "9"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.7235421969327254`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Det", "[", "A", "]"}]], "Input",
 CellChangeTimes->{{3.7235421981807275`*^9, 3.723542200021531*^9}}],

Cell[BoxData["108"], "Output",
 CellChangeTimes->{3.7235422003335314`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Tr", "[", "A", "]"}]], "Input",
 CellChangeTimes->{{3.7235422011447325`*^9, 3.7235422048887396`*^9}}],

Cell[BoxData["15"], "Output",
 CellChangeTimes->{3.7235422055907407`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MatrixRank", "[", "A", "]"}]], "Input",
 CellChangeTimes->{{3.7235422066671424`*^9, 3.7235422129383535`*^9}}],

Cell[BoxData["3"], "Output",
 CellChangeTimes->{3.7235422134843545`*^9}]
}, Open  ]],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.723542062242089*^9, 3.7235420626788893`*^9}}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.72354214264463*^9, 3.7235421435026317`*^9}}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.723541586893654*^9, 3.7235415876736555`*^9}}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.7235414015809283`*^9, 3.72354140251693*^9}}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.7235409182608795`*^9, 3.7235409195556817`*^9}}]
},
WindowSize->{759, 586},
WindowMargins->{{Automatic, 265}, {-13, Automatic}},
FrontEndVersion->"11.0 for Microsoft Windows (64-bit) (September 21, 2016)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 679, 11, 125, "Text"],
Cell[CellGroupData[{
Cell[1262, 35, 639, 17, 50, "Input"],
Cell[1904, 54, 122, 3, 30, "Output"]
}, Open  ]],
Cell[2041, 60, 755, 19, 296, "Text"],
Cell[2799, 81, 611, 17, 30, "Input"],
Cell[3413, 100, 159, 3, 30, "Text"],
Cell[3575, 105, 299, 8, 30, "Input"],
Cell[3877, 115, 247, 5, 49, "Text"],
Cell[CellGroupData[{
Cell[4149, 124, 905, 27, 50, "Input"],
Cell[5057, 153, 305, 10, 49, "Output"]
}, Open  ]],
Cell[5377, 166, 686, 13, 182, "Text"],
Cell[CellGroupData[{
Cell[6088, 183, 651, 19, 30, "Input"],
Cell[6742, 204, 150739, 2531, 235, "Output"]
}, Open  ]],
Cell[157496, 2738, 169, 2, 30, "Text"],
Cell[CellGroupData[{
Cell[157690, 2744, 395, 11, 49, "Input"],
Cell[158088, 2757, 283, 6, 30, "Output"]
}, Open  ]],
Cell[158386, 2766, 154, 3, 30, "Text"],
Cell[CellGroupData[{
Cell[158565, 2773, 463, 13, 52, "Input"],
Cell[159031, 2788, 799, 29, 43, "Output"]
}, Open  ]],
Cell[159845, 2820, 136, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[160006, 2825, 268, 7, 30, "Input"],
Cell[160277, 2834, 1009, 35, 43, "Output"]
}, Open  ]],
Cell[161301, 2872, 168, 4, 49, "Text"],
Cell[CellGroupData[{
Cell[161494, 2880, 236, 5, 30, "Input"],
Cell[161733, 2887, 147, 3, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[161917, 2895, 266, 6, 30, "Input"],
Cell[162186, 2903, 168, 4, 30, "Output"]
}, Open  ]],
Cell[162369, 2910, 142, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[162536, 2915, 119, 2, 30, "Input"],
Cell[162658, 2919, 168, 4, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[162863, 2928, 129, 2, 30, "Input"],
Cell[162995, 2932, 146, 4, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[163178, 2941, 177, 4, 30, "Input"],
Cell[163358, 2947, 148, 4, 30, "Output"]
}, Open  ]],
Cell[163521, 2954, 340, 7, 106, "Text"],
Cell[CellGroupData[{
Cell[163886, 2965, 121, 2, 30, "Input"],
Cell[164010, 2969, 145, 4, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[164192, 2978, 121, 2, 30, "Input"],
Cell[164316, 2982, 72, 1, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[164425, 2988, 149, 3, 30, "Input"],
Cell[164577, 2993, 149, 4, 30, "Output"]
}, Open  ]],
Cell[164741, 3000, 258, 5, 49, "Text"],
Cell[CellGroupData[{
Cell[165024, 3009, 414, 11, 30, "Input"],
Cell[165441, 3022, 165, 5, 56, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[165643, 3032, 162, 3, 30, "Input"],
Cell[165808, 3037, 163, 5, 56, "Output"]
}, Open  ]],
Cell[165986, 3045, 110, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[166121, 3050, 120, 2, 30, "Input"],
Cell[166244, 3054, 88, 1, 30, "Output"]
}, Open  ]],
Cell[166347, 3058, 154, 2, 30, "Text"],
Cell[CellGroupData[{
Cell[166526, 3064, 196, 3, 30, "Input"],
Cell[166725, 3069, 113, 1, 30, "Output"]
}, Open  ]],
Cell[166853, 3073, 138, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[167016, 3078, 350, 9, 30, "Input"],
Cell[167369, 3089, 130, 4, 56, "Output"]
}, Open  ]],
Cell[167514, 3096, 201, 4, 49, "Text"],
Cell[CellGroupData[{
Cell[167740, 3104, 232, 6, 30, "Input"],
Cell[167975, 3112, 165, 5, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[168177, 3122, 250, 6, 30, "Input"],
Cell[168430, 3130, 98, 1, 30, "Output"]
}, Open  ]],
Cell[168543, 3134, 137, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[168705, 3139, 192, 4, 30, "Input"],
Cell[168900, 3145, 217, 7, 43, "Output"]
}, Open  ]],
Cell[169132, 3155, 164, 3, 30, "Text"],
Cell[CellGroupData[{
Cell[169321, 3162, 176, 4, 30, "Input"],
Cell[169500, 3168, 98, 1, 30, "Output"]
}, Open  ]],
Cell[169613, 3172, 216, 4, 49, "Text"],
Cell[CellGroupData[{
Cell[169854, 3180, 148, 3, 30, "Input"],
Cell[170005, 3185, 96, 1, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[170138, 3191, 94, 1, 30, "Input"],
Cell[170235, 3194, 127, 3, 30, "Output"]
}, Open  ]],
Cell[170377, 3200, 162, 3, 30, "Text"],
Cell[CellGroupData[{
Cell[170564, 3207, 180, 4, 30, "Input"],
Cell[170747, 3213, 71, 1, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[170855, 3219, 98, 1, 30, "Input"],
Cell[170956, 3222, 128, 3, 30, "Output"]
}, Open  ]],
Cell[171099, 3228, 174, 4, 30, "Text"],
Cell[CellGroupData[{
Cell[171298, 3236, 367, 10, 30, "Input"],
Cell[171668, 3248, 304, 9, 30, "Output"]
}, Open  ]],
Cell[171987, 3260, 175, 4, 30, "Text"],
Cell[CellGroupData[{
Cell[172187, 3268, 199, 5, 30, "Input"],
Cell[172389, 3275, 69, 1, 30, "Output"]
}, Open  ]],
Cell[172473, 3279, 94, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[172592, 3284, 167, 4, 30, "Input"],
Cell[172762, 3290, 70, 1, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[172869, 3296, 205, 5, 30, "Input"],
Cell[173077, 3303, 73, 1, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[173187, 3309, 71, 1, 30, "Input"],
Cell[173261, 3312, 305, 9, 30, "Output"]
}, Open  ]],
Cell[173581, 3324, 475, 8, 106, "Text"],
Cell[CellGroupData[{
Cell[174081, 3336, 125, 2, 30, "Input"],
Cell[174209, 3340, 662, 19, 77, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[174908, 3364, 378, 10, 30, "Input"],
Cell[175289, 3376, 310, 9, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[175636, 3390, 120, 2, 30, "Input"],
Cell[175759, 3394, 313, 9, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[176109, 3408, 127, 2, 30, "Input"],
Cell[176239, 3412, 670, 19, 77, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[176946, 3436, 117, 2, 30, "Input"],
Cell[177066, 3440, 472, 17, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[177575, 3462, 115, 2, 30, "Input"],
Cell[177693, 3466, 315, 9, 30, "Output"]
}, Open  ]],
Cell[178023, 3478, 280, 5, 68, "Text"],
Cell[CellGroupData[{
Cell[178328, 3487, 117, 2, 30, "Input"],
Cell[178448, 3491, 322, 9, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[178807, 3505, 115, 2, 30, "Input"],
Cell[178925, 3509, 322, 9, 30, "Output"]
}, Open  ]],
Cell[179262, 3521, 251, 5, 49, "Text"],
Cell[CellGroupData[{
Cell[179538, 3530, 117, 2, 30, "Input"],
Cell[179658, 3534, 333, 9, 30, "Output"]
}, Open  ]],
Cell[180006, 3546, 129, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[180160, 3551, 161, 4, 30, "Input"],
Cell[180324, 3557, 495, 17, 43, "Output"]
}, Open  ]],
Cell[180834, 3577, 144, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[181003, 3582, 162, 3, 30, "Input"],
Cell[181168, 3587, 640, 23, 43, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[181845, 3615, 118, 2, 30, "Input"],
Cell[181966, 3619, 304, 9, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[182307, 3633, 159, 3, 30, "Input"],
Cell[182469, 3638, 659, 19, 77, "Output"]
}, Open  ]],
Cell[183143, 3660, 310, 10, 163, "Text"],
Cell[CellGroupData[{
Cell[183478, 3674, 137, 2, 30, "Input"],
Cell[183618, 3678, 304, 9, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[183959, 3692, 192, 4, 30, "Input"],
Cell[184154, 3698, 304, 9, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[184495, 3712, 212, 5, 30, "Input"],
Cell[184710, 3719, 274, 9, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[185021, 3733, 130, 2, 30, "Input"],
Cell[185154, 3737, 305, 9, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[185496, 3751, 124, 2, 30, "Input"],
Cell[185623, 3755, 74, 1, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[185734, 3761, 125, 2, 30, "Input"],
Cell[185862, 3765, 73, 1, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[185972, 3771, 133, 2, 30, "Input"],
Cell[186108, 3775, 72, 1, 63, "Output"]
}, Open  ]],
Cell[186195, 3779, 94, 1, 30, "Input"],
Cell[186292, 3782, 93, 1, 30, "Input"],
Cell[186388, 3785, 94, 1, 30, "Input"],
Cell[186485, 3788, 93, 1, 30, "Input"],
Cell[186581, 3791, 96, 1, 30, "Input"]
}
]
*)

